Rdim=0.01; % spinal cord radius [m]  
L=0.5; %spinal cord length [m] 
delta=Rdim/L;%[-]
nu=0.35; %Poisson coefficient [-] 
rho=1000; % CSF density [kg/m^3] 
mu=0.001; % CSF dynamic viscosity [Pa*s]
T0=1; %characteristic time [s]
kappa=1.4*10^-14; %permeability of the CSF network [m^2]
V0=0.1; %characteristic velocity [m/s]
Y=0.54*10^6; %Young modulus [Pa]
k=0.22; %dimensionless wave numer [-]
alpha=0.9; % Biot coefficient [-]
Ri=0.05; %dimensionless central canal radius [-]
Q=1.2*10^6; %compressibility of the fluid-solid system 
h=0.5; %dimensionless thickness of the SAS
phi=0.4; %porosity of the spinal cord
[G]=(1/2).*(1+nu).^(-1).*Y; %shear modulus [Pa]
[Pdim]=kappa.^(-1).*mu.^2.*rho.^(-1); %scaling factor to adimensionalize the pressures [Pa]
Pes=1350/Pdim; %dimensionless static CSF pressure [-]
Pvs=865/Pdim; %dimensionless static venous pressure [-]
Pcs=3200/Pdim;%dimensionless static capillary pressure [-]
Pc=400/Pdim;%dimensionless amplitude of the capillary pressure wave at the SC-SAS interface  
Pv=65/Pdim; %dimensionless amplitude of the venous pressure wave at the SC-SAS interface
P0=200/Pdim;%dimensionless amplitude of the CSF pressure wave in the SAS

%dimensionless coefficient 
[gamma]=(delta.^2.*k.^2+(sqrt(-1)*(-2)).*mu.^(-1).*pi.*Rdim.^2.*rho.*T0.^(-1)) ...
  .^(1/2); 
[xi1]=2.*mu.^(-1).*pi.*Rdim.^2.*rho.*T0.^(-1);
[xi2]=kappa.^(-1).*L.^(-1).*mu.*Rdim.^2.*rho.^(-1).*V0.^(-1);
[eta1]=delta.*(1+(-2).*nu).^(-1);
[eta2]=2.*alpha.*kappa.^(-1).*mu.^2.*(1+nu).*rho.^(-1).*Y.^(-1);
[eta3]=kappa.^(-1).*mu.^2.*Q.^(-1).*rho.^(-1);
[eta4]=(1/2).*L.^(-2).*mu.*pi.^(-1).*rho.^(-1).*T0;
[eta5]=2.*mu.*(1+nu).*Rdim.^(-1).*V0.*Y.^(-1);
eta6=2.*delta.*mu.^(-1).*pi.*Rdim.^2.*rho.*T0.^(-1);
Rey=mu.^(-1).*Rdim.*V0.*rho; %Reynolds number [-]

%radial velocity derivative at the SC-SAS interface (ze=0)
[dvr0]=(-1/2).*gamma.^(-2).*h.*k.^2.*P0.*(delta.^2.*k.^2+(sqrt(-1)*(-1)).*xi1) ...
  .^(-1).*xi2.*(besseli(0,gamma.*(1+h)).*besselk(0,gamma)+(-1).*besseli(0, ...
  gamma).*besselk(0,gamma.*(1+h))).^(-1).*(4+gamma.*(gamma.*besseli(2, ...
  gamma).*besselk(0,gamma.*(1+h))+besseli(0,gamma.*(1+h)).*(gamma.*h.*(2+ ...
  h).*besselk(0,gamma)+(-2).*besselk(1,gamma))+(-1).*(1+h).*(2.*besseli(1, ...
  gamma.*(1+h)).*besselk(0,gamma)+gamma.*(1+h).*besseli(0,gamma).*besselk( ...
  2,gamma.*(1+h)))));

%radial velocity at ze=0
[vr0]=(-1/2).*gamma.^(-1).*k.^2.*P0.*(delta.^2.*k.^2+(sqrt(-1)*(-1)).*xi1).^( ...
  -1).*xi2.*(besseli(0,gamma.*(1+h)).*besselk(0,gamma)+(-1).*besseli(0, ...
  gamma).*besselk(0,gamma.*(1+h))).^(-1).*((-2).*gamma.^(-1)+2.*(1+h).* ...
  besseli(1,gamma.*(1+h)).*besselk(0,gamma)+2.*besseli(1,gamma).*((-1).* ...
  besselk(0,gamma)+besselk(0,gamma.*(1+h)))+besseli(0,gamma.*(1+h)).*((-1) ...
  .*gamma.*h.*(2+h).*besselk(0,gamma)+2.*besselk(1,gamma))+besseli(0, ...
  gamma).*(gamma.*h.*(2+h).*besselk(0,gamma.*(1+h))+(-2).*besselk(1,gamma) ...
  +2.*(1+h).*besselk(1,gamma.*(1+h))));

%axial velocity derivative at ze=0
[dvx0]=h.*k.*P0.*(sqrt(-1).*delta.^2.*k.^2+xi1).^(-1).*xi2.*(besseli(0,gamma.*( ...
  1+h)).*besselk(0,gamma)+(-1).*besseli(0,gamma).*besselk(0,gamma.*(1+h))) ...
  .^(-1).*((-1)+gamma.*besseli(1,gamma).*besselk(0,gamma.*(1+h))+gamma.* ...
  besseli(0,gamma.*(1+h)).*besselk(1,gamma));

%radial displacement of the spinal cord at zs=1
[psi]=eta5.*((-1).*dvr0+sqrt(-1).*delta.^(-2).*dvx0.*k.^(-1)+vr0+(-1).*h.*vr0) ...
;

%capillary pressure value at the CC-SC interface (zs=Ri)
[pcRi]=(kappa.^(-1).*mu.^2.*Q.^(-1).*rho.^(-1)+(sqrt(-1)*(1/2)).*k.^2.*L.^(-2) ...
  .*mu.*pi.^(-1).*rho.^(-1).*T0).^(-1).*(besselj(1,sqrt(-1).*delta.*(2.* ...
  pi).^(1/2).*Ri.*(L.^(-2).*mu.*rho.^(-1).*T0).^(-1/2).*((sqrt(-1)*(-1)).* ...
  kappa.^(-1).*mu.^2.*Q.^(-1).*rho.^(-1)+(1/2).*k.^2.*L.^(-2).*mu.*pi.^( ...
  -1).*rho.^(-1).*T0).^(1/2)).*bessely(0,(sqrt(-1)*(-1)).*delta.*(2.*pi) ...
  .^(1/2).*(L.^(-2).*mu.*rho.^(-1).*T0).^(-1/2).*((sqrt(-1)*(-1)).* ...
  kappa.^(-1).*mu.^2.*Q.^(-1).*rho.^(-1)+(1/2).*k.^2.*L.^(-2).*mu.*pi.^( ...
  -1).*rho.^(-1).*T0).^(1/2))+besselj(0,sqrt(-1).*delta.*(2.*pi).^(1/2).*( ...
  L.^(-2).*mu.*rho.^(-1).*T0).^(-1/2).*((sqrt(-1)*(-1)).*kappa.^(-1).* ...
  mu.^2.*Q.^(-1).*rho.^(-1)+(1/2).*k.^2.*L.^(-2).*mu.*pi.^(-1).*rho.^(-1) ...
  .*T0).^(1/2)).*bessely(1,(sqrt(-1)*(-1)).*delta.*(2.*pi).^(1/2).*Ri.*( ...
  L.^(-2).*mu.*rho.^(-1).*T0).^(-1/2).*((sqrt(-1)*(-1)).*kappa.^(-1).* ...
  mu.^2.*Q.^(-1).*rho.^(-1)+(1/2).*k.^2.*L.^(-2).*mu.*pi.^(-1).*rho.^(-1) ...
  .*T0).^(1/2))).^(-1).*(besselj(1,sqrt(-1).*delta.*(2.*pi).^(1/2).*Ri.*( ...
  L.^(-2).*mu.*rho.^(-1).*T0).^(-1/2).*((sqrt(-1)*(-1)).*kappa.^(-1).* ...
  mu.^2.*Q.^(-1).*rho.^(-1)+(1/2).*k.^2.*L.^(-2).*mu.*pi.^(-1).*rho.^(-1) ...
  .*T0).^(1/2)).*((-2).*alpha.*delta.*psi.*bessely(0,(sqrt(-1)*(-1)).* ...
  delta.*(2.*pi).^(1/2).*(L.^(-2).*mu.*rho.^(-1).*T0).^(-1/2).*((sqrt(-1)* ...
  (-1)).*kappa.^(-1).*mu.^2.*Q.^(-1).*rho.^(-1)+(1/2).*k.^2.*L.^(-2).*mu.* ...
  pi.^(-1).*rho.^(-1).*T0).^(1/2))+(2.*alpha.*delta.*psi+kappa.^(-1).* ...
  mu.^2.*Pc.*Q.^(-1).*rho.^(-1)+(sqrt(-1)*(1/2)).*k.^2.*L.^(-2).*mu.*Pc.* ...
  pi.^(-1).*rho.^(-1).*T0).*bessely(0,(sqrt(-1)*(-1)).*delta.*(2.*pi).^( ...
  1/2).*Ri.*(L.^(-2).*mu.*rho.^(-1).*T0).^(-1/2).*((sqrt(-1)*(-1)).* ...
  kappa.^(-1).*mu.^2.*Q.^(-1).*rho.^(-1)+(1/2).*k.^2.*L.^(-2).*mu.*pi.^( ...
  -1).*rho.^(-1).*T0).^(1/2)))+((-2).*alpha.*delta.*psi.*besselj(0,sqrt( ...
  -1).*delta.*(2.*pi).^(1/2).*(L.^(-2).*mu.*rho.^(-1).*T0).^(-1/2).*(( ...
  sqrt(-1)*(-1)).*kappa.^(-1).*mu.^2.*Q.^(-1).*rho.^(-1)+(1/2).*k.^2.*L.^( ...
  -2).*mu.*pi.^(-1).*rho.^(-1).*T0).^(1/2))+(2.*alpha.*delta.*psi+kappa.^( ...
  -1).*mu.^2.*Pc.*Q.^(-1).*rho.^(-1)+(sqrt(-1)*(1/2)).*k.^2.*L.^(-2).*mu.* ...
  Pc.*pi.^(-1).*rho.^(-1).*T0).*besselj(0,sqrt(-1).*delta.*(2.*pi).^(1/2) ...
  .*Ri.*(L.^(-2).*mu.*rho.^(-1).*T0).^(-1/2).*((sqrt(-1)*(-1)).*kappa.^( ...
  -1).*mu.^2.*Q.^(-1).*rho.^(-1)+(1/2).*k.^2.*L.^(-2).*mu.*pi.^(-1).* ...
  rho.^(-1).*T0).^(1/2))).*bessely(1,(sqrt(-1)*(-1)).*delta.*(2.*pi).^( ...
  1/2).*Ri.*(L.^(-2).*mu.*rho.^(-1).*T0).^(-1/2).*((sqrt(-1)*(-1)).* ...
  kappa.^(-1).*mu.^2.*Q.^(-1).*rho.^(-1)+(1/2).*k.^2.*L.^(-2).*mu.*pi.^( ...
  -1).*rho.^(-1).*T0).^(1/2)));

%venous pressure value at zs=Ri 
[pvRi]=(kappa.^(-1).*mu.^2.*Q.^(-1).*rho.^(-1)+(sqrt(-1)*(1/2)).*k.^2.*L.^(-2) ...
  .*mu.*pi.^(-1).*rho.^(-1).*T0).^(-1).*(besselj(1,sqrt(-1).*delta.*(2.* ...
  pi).^(1/2).*Ri.*(L.^(-2).*mu.*rho.^(-1).*T0).^(-1/2).*((sqrt(-1)*(-1)).* ...
  kappa.^(-1).*mu.^2.*Q.^(-1).*rho.^(-1)+(1/2).*k.^2.*L.^(-2).*mu.*pi.^( ...
  -1).*rho.^(-1).*T0).^(1/2)).*bessely(0,(sqrt(-1)*(-1)).*delta.*(2.*pi) ...
  .^(1/2).*(L.^(-2).*mu.*rho.^(-1).*T0).^(-1/2).*((sqrt(-1)*(-1)).* ...
  kappa.^(-1).*mu.^2.*Q.^(-1).*rho.^(-1)+(1/2).*k.^2.*L.^(-2).*mu.*pi.^( ...
  -1).*rho.^(-1).*T0).^(1/2))+besselj(0,sqrt(-1).*delta.*(2.*pi).^(1/2).*( ...
  L.^(-2).*mu.*rho.^(-1).*T0).^(-1/2).*((sqrt(-1)*(-1)).*kappa.^(-1).* ...
  mu.^2.*Q.^(-1).*rho.^(-1)+(1/2).*k.^2.*L.^(-2).*mu.*pi.^(-1).*rho.^(-1) ...
  .*T0).^(1/2)).*bessely(1,(sqrt(-1)*(-1)).*delta.*(2.*pi).^(1/2).*Ri.*( ...
  L.^(-2).*mu.*rho.^(-1).*T0).^(-1/2).*((sqrt(-1)*(-1)).*kappa.^(-1).* ...
  mu.^2.*Q.^(-1).*rho.^(-1)+(1/2).*k.^2.*L.^(-2).*mu.*pi.^(-1).*rho.^(-1) ...
  .*T0).^(1/2))).^(-1).*(besselj(1,sqrt(-1).*delta.*(2.*pi).^(1/2).*Ri.*( ...
  L.^(-2).*mu.*rho.^(-1).*T0).^(-1/2).*((sqrt(-1)*(-1)).*kappa.^(-1).* ...
  mu.^2.*Q.^(-1).*rho.^(-1)+(1/2).*k.^2.*L.^(-2).*mu.*pi.^(-1).*rho.^(-1) ...
  .*T0).^(1/2)).*((-2).*alpha.*delta.*psi.*bessely(0,(sqrt(-1)*(-1)).* ...
  delta.*(2.*pi).^(1/2).*(L.^(-2).*mu.*rho.^(-1).*T0).^(-1/2).*((sqrt(-1)* ...
  (-1)).*kappa.^(-1).*mu.^2.*Q.^(-1).*rho.^(-1)+(1/2).*k.^2.*L.^(-2).*mu.* ...
  pi.^(-1).*rho.^(-1).*T0).^(1/2))+(2.*alpha.*delta.*psi+kappa.^(-1).* ...
  mu.^2.*Pv.*Q.^(-1).*rho.^(-1)+(sqrt(-1)*(1/2)).*k.^2.*L.^(-2).*mu.*Pv.* ...
  pi.^(-1).*rho.^(-1).*T0).*bessely(0,(sqrt(-1)*(-1)).*delta.*(2.*pi).^( ...
  1/2).*Ri.*(L.^(-2).*mu.*rho.^(-1).*T0).^(-1/2).*((sqrt(-1)*(-1)).* ...
  kappa.^(-1).*mu.^2.*Q.^(-1).*rho.^(-1)+(1/2).*k.^2.*L.^(-2).*mu.*pi.^( ...
  -1).*rho.^(-1).*T0).^(1/2)))+((-2).*alpha.*delta.*psi.*besselj(0,sqrt( ...
  -1).*delta.*(2.*pi).^(1/2).*(L.^(-2).*mu.*rho.^(-1).*T0).^(-1/2).*(( ...
  sqrt(-1)*(-1)).*kappa.^(-1).*mu.^2.*Q.^(-1).*rho.^(-1)+(1/2).*k.^2.*L.^( ...
  -2).*mu.*pi.^(-1).*rho.^(-1).*T0).^(1/2))+(2.*alpha.*delta.*psi+kappa.^( ...
  -1).*mu.^2.*Pv.*Q.^(-1).*rho.^(-1)+(sqrt(-1)*(1/2)).*k.^2.*L.^(-2).*mu.* ...
  Pv.*pi.^(-1).*rho.^(-1).*T0).*besselj(0,sqrt(-1).*delta.*(2.*pi).^(1/2) ...
  .*Ri.*(L.^(-2).*mu.*rho.^(-1).*T0).^(-1/2).*((sqrt(-1)*(-1)).*kappa.^( ...
  -1).*mu.^2.*Q.^(-1).*rho.^(-1)+(1/2).*k.^2.*L.^(-2).*mu.*pi.^(-1).* ...
  rho.^(-1).*T0).^(1/2))).*bessely(1,(sqrt(-1)*(-1)).*delta.*(2.*pi).^( ...
  1/2).*Ri.*(L.^(-2).*mu.*rho.^(-1).*T0).^(-1/2).*((sqrt(-1)*(-1)).* ...
  kappa.^(-1).*mu.^2.*Q.^(-1).*rho.^(-1)+(1/2).*k.^2.*L.^(-2).*mu.*pi.^( ...
  -1).*rho.^(-1).*T0).^(1/2)));

pv1=Pv; %boundary condition for the venous pressure at SC-SAS interface (zs=1)

pc1=Pc; %boundary condition for the capillary pressure at zs=1

zs=[0.05:0.001:1]; %radial coordinate

%cerebrospinal pressure distribution inside the spinal cord 
[pe]=alpha.^(-1).*eta2.^(-1).*(eta3+sqrt(-1).*eta4.*k.^2).^(-1).*((-1).* ...
  delta.*((sqrt(-1)*(-1)).*eta3+eta4.*k.^2).^(1/2).*phi.*((-1).*Pes+ ...
  alpha.*(Pcs+Pes+Pvs)).*besselj(1,sqrt(-1).*delta.*eta4.^(-1/2).*((sqrt( ...
  -1)*(-1)).*eta3+eta4.*k.^2).^(1/2)).*(h.*bessely(0,(sqrt(-1)*(-1)).* ...
  delta.*eta4.^(-1/2).*((sqrt(-1)*(-1)).*eta3+eta4.*k.^2).^(1/2))+(-1).*(( ...
  -1)+h).*bessely(0,(sqrt(-1)*(-1)).*delta.*eta4.^(-1/2).*((sqrt(-1)*(-1)) ...
  .*eta3+eta4.*k.^2).^(1/2).*Ri))+(-1).*h.*besselj(0,sqrt(-1).*delta.* ...
  eta4.^(-1/2).*((sqrt(-1)*(-1)).*eta3+eta4.*k.^2).^(1/2)).*(alpha.* ...
  eta4.^(1/2).*eta6.*((-1)+phi).*bessely(0,(sqrt(-1)*(-1)).*delta.*eta4.^( ...
  -1/2).*((sqrt(-1)*(-1)).*eta3+eta4.*k.^2).^(1/2).*Ri)+delta.*((sqrt(-1)* ...
  (-1)).*eta3+eta4.*k.^2).^(1/2).*phi.*((-1).*Pes+alpha.*(Pcs+Pes+Pvs)).* ...
  bessely(1,(sqrt(-1)*(-1)).*delta.*eta4.^(-1/2).*((sqrt(-1)*(-1)).*eta3+ ...
  eta4.*k.^2).^(1/2)))+besselj(0,sqrt(-1).*delta.*eta4.^(-1/2).*((sqrt(-1) ...
  *(-1)).*eta3+eta4.*k.^2).^(1/2).*Ri).*(alpha.*eta4.^(1/2).*eta6.*h.*(( ...
  -1)+phi).*bessely(0,(sqrt(-1)*(-1)).*delta.*eta4.^(-1/2).*((sqrt(-1)*( ...
  -1)).*eta3+eta4.*k.^2).^(1/2))+delta.*((-1)+h).*((sqrt(-1)*(-1)).*eta3+ ...
  eta4.*k.^2).^(1/2).*phi.*((-1).*Pes+alpha.*(Pcs+Pes+Pvs)).*bessely(1,( ...
  sqrt(-1)*(-1)).*delta.*eta4.^(-1/2).*((sqrt(-1)*(-1)).*eta3+eta4.*k.^2) ...
  .^(1/2)))).^(-1).*(2.*alpha.^3.*delta.^2.*eta2.*h.*((sqrt(-1)*(-1)).* ...
  eta3+eta4.*k.^2).^(1/2).*Pcs.*phi.*psi.*besselj(1,sqrt(-1).*delta.* ...
  eta4.^(-1/2).*((sqrt(-1)*(-1)).*eta3+eta4.*k.^2).^(1/2)).*bessely(0,( ...
  sqrt(-1)*(-1)).*delta.*eta4.^(-1/2).*((sqrt(-1)*(-1)).*eta3+eta4.*k.^2) ...
  .^(1/2))+(-2).*alpha.^2.*delta.^2.*eta2.*h.*((sqrt(-1)*(-1)).*eta3+ ...
  eta4.*k.^2).^(1/2).*Pes.*phi.*psi.*besselj(1,sqrt(-1).*delta.*eta4.^( ...
  -1/2).*((sqrt(-1)*(-1)).*eta3+eta4.*k.^2).^(1/2)).*bessely(0,(sqrt(-1)*( ...
  -1)).*delta.*eta4.^(-1/2).*((sqrt(-1)*(-1)).*eta3+eta4.*k.^2).^(1/2))+ ...
  2.*alpha.^3.*delta.^2.*eta2.*h.*((sqrt(-1)*(-1)).*eta3+eta4.*k.^2).^( ...
  1/2).*Pes.*phi.*psi.*besselj(1,sqrt(-1).*delta.*eta4.^(-1/2).*((sqrt(-1) ...
  *(-1)).*eta3+eta4.*k.^2).^(1/2)).*bessely(0,(sqrt(-1)*(-1)).*delta.* ...
  eta4.^(-1/2).*((sqrt(-1)*(-1)).*eta3+eta4.*k.^2).^(1/2))+2.*alpha.^3.* ...
  delta.^2.*eta2.*h.*((sqrt(-1)*(-1)).*eta3+eta4.*k.^2).^(1/2).*phi.*psi.* ...
  Pvs.*besselj(1,sqrt(-1).*delta.*eta4.^(-1/2).*((sqrt(-1)*(-1)).*eta3+ ...
  eta4.*k.^2).^(1/2)).*bessely(0,(sqrt(-1)*(-1)).*delta.*eta4.^(-1/2).*(( ...
  sqrt(-1)*(-1)).*eta3+eta4.*k.^2).^(1/2))+(-2).*alpha.^3.*delta.*eta2.* ...
  eta4.^(1/2).*eta6.*h.*psi.*besselj(0,sqrt(-1).*delta.*eta4.^(-1/2).*(( ...
  sqrt(-1)*(-1)).*eta3+eta4.*k.^2).^(1/2)).*bessely(0,(sqrt(-1)*(-1)).* ...
  delta.*eta4.^(-1/2).*((sqrt(-1)*(-1)).*eta3+eta4.*k.^2).^(1/2).*Ri)+2.* ...
  alpha.^3.*delta.*eta2.*eta4.^(1/2).*eta6.*h.*phi.*psi.*besselj(0,sqrt( ...
  -1).*delta.*eta4.^(-1/2).*((sqrt(-1)*(-1)).*eta3+eta4.*k.^2).^(1/2)).* ...
  bessely(0,(sqrt(-1)*(-1)).*delta.*eta4.^(-1/2).*((sqrt(-1)*(-1)).*eta3+ ...
  eta4.*k.^2).^(1/2).*Ri)+2.*alpha.^3.*delta.^2.*eta2.*((sqrt(-1)*(-1)).* ...
  eta3+eta4.*k.^2).^(1/2).*Pcs.*phi.*psi.*besselj(1,sqrt(-1).*delta.* ...
  eta4.^(-1/2).*((sqrt(-1)*(-1)).*eta3+eta4.*k.^2).^(1/2)).*bessely(0,( ...
  sqrt(-1)*(-1)).*delta.*eta4.^(-1/2).*((sqrt(-1)*(-1)).*eta3+eta4.*k.^2) ...
  .^(1/2).*Ri)+(-2).*alpha.^3.*delta.^2.*eta2.*h.*((sqrt(-1)*(-1)).*eta3+ ...
  eta4.*k.^2).^(1/2).*Pcs.*phi.*psi.*besselj(1,sqrt(-1).*delta.*eta4.^( ...
  -1/2).*((sqrt(-1)*(-1)).*eta3+eta4.*k.^2).^(1/2)).*bessely(0,(sqrt(-1)*( ...
  -1)).*delta.*eta4.^(-1/2).*((sqrt(-1)*(-1)).*eta3+eta4.*k.^2).^(1/2).* ...
  Ri)+(-2).*alpha.^2.*delta.^2.*eta2.*((sqrt(-1)*(-1)).*eta3+eta4.*k.^2) ...
  .^(1/2).*Pes.*phi.*psi.*besselj(1,sqrt(-1).*delta.*eta4.^(-1/2).*((sqrt( ...
  -1)*(-1)).*eta3+eta4.*k.^2).^(1/2)).*bessely(0,(sqrt(-1)*(-1)).*delta.* ...
  eta4.^(-1/2).*((sqrt(-1)*(-1)).*eta3+eta4.*k.^2).^(1/2).*Ri)+2.* ...
  alpha.^3.*delta.^2.*eta2.*((sqrt(-1)*(-1)).*eta3+eta4.*k.^2).^(1/2).* ...
  Pes.*phi.*psi.*besselj(1,sqrt(-1).*delta.*eta4.^(-1/2).*((sqrt(-1)*(-1)) ...
  .*eta3+eta4.*k.^2).^(1/2)).*bessely(0,(sqrt(-1)*(-1)).*delta.*eta4.^( ...
  -1/2).*((sqrt(-1)*(-1)).*eta3+eta4.*k.^2).^(1/2).*Ri)+2.*alpha.^2.* ...
  delta.^2.*eta2.*h.*((sqrt(-1)*(-1)).*eta3+eta4.*k.^2).^(1/2).*Pes.*phi.* ...
  psi.*besselj(1,sqrt(-1).*delta.*eta4.^(-1/2).*((sqrt(-1)*(-1)).*eta3+ ...
  eta4.*k.^2).^(1/2)).*bessely(0,(sqrt(-1)*(-1)).*delta.*eta4.^(-1/2).*(( ...
  sqrt(-1)*(-1)).*eta3+eta4.*k.^2).^(1/2).*Ri)+(-2).*alpha.^3.*delta.^2.* ...
  eta2.*h.*((sqrt(-1)*(-1)).*eta3+eta4.*k.^2).^(1/2).*Pes.*phi.*psi.* ...
  besselj(1,sqrt(-1).*delta.*eta4.^(-1/2).*((sqrt(-1)*(-1)).*eta3+eta4.* ...
  k.^2).^(1/2)).*bessely(0,(sqrt(-1)*(-1)).*delta.*eta4.^(-1/2).*((sqrt( ...
  -1)*(-1)).*eta3+eta4.*k.^2).^(1/2).*Ri)+2.*alpha.^3.*delta.^2.*eta2.*(( ...
  sqrt(-1)*(-1)).*eta3+eta4.*k.^2).^(1/2).*phi.*psi.*Pvs.*besselj(1,sqrt( ...
  -1).*delta.*eta4.^(-1/2).*((sqrt(-1)*(-1)).*eta3+eta4.*k.^2).^(1/2)).* ...
  bessely(0,(sqrt(-1)*(-1)).*delta.*eta4.^(-1/2).*((sqrt(-1)*(-1)).*eta3+ ...
  eta4.*k.^2).^(1/2).*Ri)+(-2).*alpha.^3.*delta.^2.*eta2.*h.*((sqrt(-1)*( ...
  -1)).*eta3+eta4.*k.^2).^(1/2).*phi.*psi.*Pvs.*besselj(1,sqrt(-1).* ...
  delta.*eta4.^(-1/2).*((sqrt(-1)*(-1)).*eta3+eta4.*k.^2).^(1/2)).* ...
  bessely(0,(sqrt(-1)*(-1)).*delta.*eta4.^(-1/2).*((sqrt(-1)*(-1)).*eta3+ ...
  eta4.*k.^2).^(1/2).*Ri)+(-1).*alpha.^2.*eta2.*eta3.*eta4.^(1/2).*eta6.* ...
  h.*pcRi.*besselj(0,sqrt(-1).*delta.*eta4.^(-1/2).*((sqrt(-1)*(-1)).* ...
  eta3+eta4.*k.^2).^(1/2)).*bessely(0,(sqrt(-1)*(-1)).*delta.*eta4.^(-1/2) ...
  .*((sqrt(-1)*(-1)).*eta3+eta4.*k.^2).^(1/2).*zs)+(sqrt(-1)*(-1)).* ...
  alpha.^2.*eta2.*eta4.^(3/2).*eta6.*h.*k.^2.*pcRi.*besselj(0,sqrt(-1).* ...
  delta.*eta4.^(-1/2).*((sqrt(-1)*(-1)).*eta3+eta4.*k.^2).^(1/2)).* ...
  bessely(0,(sqrt(-1)*(-1)).*delta.*eta4.^(-1/2).*((sqrt(-1)*(-1)).*eta3+ ...
  eta4.*k.^2).^(1/2).*zs)+alpha.^2.*eta2.*eta3.*eta4.^(1/2).*eta6.*h.* ...
  pcRi.*phi.*besselj(0,sqrt(-1).*delta.*eta4.^(-1/2).*((sqrt(-1)*(-1)).* ...
  eta3+eta4.*k.^2).^(1/2)).*bessely(0,(sqrt(-1)*(-1)).*delta.*eta4.^(-1/2) ...
  .*((sqrt(-1)*(-1)).*eta3+eta4.*k.^2).^(1/2).*zs)+sqrt(-1).*alpha.^2.* ...
  eta2.*eta4.^(3/2).*eta6.*h.*k.^2.*pcRi.*phi.*besselj(0,sqrt(-1).*delta.* ...
  eta4.^(-1/2).*((sqrt(-1)*(-1)).*eta3+eta4.*k.^2).^(1/2)).*bessely(0,( ...
  sqrt(-1)*(-1)).*delta.*eta4.^(-1/2).*((sqrt(-1)*(-1)).*eta3+eta4.*k.^2) ...
  .^(1/2).*zs)+2.*alpha.^3.*delta.*eta2.*eta4.^(1/2).*eta6.*h.*psi.* ...
  besselj(0,sqrt(-1).*delta.*eta4.^(-1/2).*((sqrt(-1)*(-1)).*eta3+eta4.* ...
  k.^2).^(1/2)).*bessely(0,(sqrt(-1)*(-1)).*delta.*eta4.^(-1/2).*((sqrt( ...
  -1)*(-1)).*eta3+eta4.*k.^2).^(1/2).*zs)+2.*alpha.^2.*delta.*eta3.* ...
  eta4.^(1/2).*eta6.*h.*psi.*besselj(0,sqrt(-1).*delta.*eta4.^(-1/2).*(( ...
  sqrt(-1)*(-1)).*eta3+eta4.*k.^2).^(1/2)).*bessely(0,(sqrt(-1)*(-1)).* ...
  delta.*eta4.^(-1/2).*((sqrt(-1)*(-1)).*eta3+eta4.*k.^2).^(1/2).*zs)+( ...
  sqrt(-1)*2).*alpha.^2.*delta.*eta4.^(3/2).*eta6.*h.*k.^2.*psi.*besselj( ...
  0,sqrt(-1).*delta.*eta4.^(-1/2).*((sqrt(-1)*(-1)).*eta3+eta4.*k.^2).^( ...
  1/2)).*bessely(0,(sqrt(-1)*(-1)).*delta.*eta4.^(-1/2).*((sqrt(-1)*(-1)) ...
  .*eta3+eta4.*k.^2).^(1/2).*zs)+2.*alpha.^2.*eta1.*eta3.*eta4.^(1/2).* ...
  eta6.*h.*nu.*psi.*besselj(0,sqrt(-1).*delta.*eta4.^(-1/2).*((sqrt(-1)*( ...
  -1)).*eta3+eta4.*k.^2).^(1/2)).*bessely(0,(sqrt(-1)*(-1)).*delta.* ...
  eta4.^(-1/2).*((sqrt(-1)*(-1)).*eta3+eta4.*k.^2).^(1/2).*zs)+(sqrt(-1)* ...
  2).*alpha.^2.*eta1.*eta4.^(3/2).*eta6.*h.*k.^2.*nu.*psi.*besselj(0,sqrt( ...
  -1).*delta.*eta4.^(-1/2).*((sqrt(-1)*(-1)).*eta3+eta4.*k.^2).^(1/2)).* ...
  bessely(0,(sqrt(-1)*(-1)).*delta.*eta4.^(-1/2).*((sqrt(-1)*(-1)).*eta3+ ...
  eta4.*k.^2).^(1/2).*zs)+(-2).*alpha.^3.*delta.*eta2.*eta4.^(1/2).*eta6.* ...
  h.*phi.*psi.*besselj(0,sqrt(-1).*delta.*eta4.^(-1/2).*((sqrt(-1)*(-1)).* ...
  eta3+eta4.*k.^2).^(1/2)).*bessely(0,(sqrt(-1)*(-1)).*delta.*eta4.^(-1/2) ...
  .*((sqrt(-1)*(-1)).*eta3+eta4.*k.^2).^(1/2).*zs)+(-2).*alpha.^2.*delta.* ...
  eta3.*eta4.^(1/2).*eta6.*h.*phi.*psi.*besselj(0,sqrt(-1).*delta.*eta4.^( ...
  -1/2).*((sqrt(-1)*(-1)).*eta3+eta4.*k.^2).^(1/2)).*bessely(0,(sqrt(-1)*( ...
  -1)).*delta.*eta4.^(-1/2).*((sqrt(-1)*(-1)).*eta3+eta4.*k.^2).^(1/2).* ...
  zs)+(sqrt(-1)*(-2)).*alpha.^2.*delta.*eta4.^(3/2).*eta6.*h.*k.^2.*phi.* ...
  psi.*besselj(0,sqrt(-1).*delta.*eta4.^(-1/2).*((sqrt(-1)*(-1)).*eta3+ ...
  eta4.*k.^2).^(1/2)).*bessely(0,(sqrt(-1)*(-1)).*delta.*eta4.^(-1/2).*(( ...
  sqrt(-1)*(-1)).*eta3+eta4.*k.^2).^(1/2).*zs)+(-2).*alpha.^2.*eta1.* ...
  eta3.*eta4.^(1/2).*eta6.*h.*nu.*phi.*psi.*besselj(0,sqrt(-1).*delta.* ...
  eta4.^(-1/2).*((sqrt(-1)*(-1)).*eta3+eta4.*k.^2).^(1/2)).*bessely(0,( ...
  sqrt(-1)*(-1)).*delta.*eta4.^(-1/2).*((sqrt(-1)*(-1)).*eta3+eta4.*k.^2) ...
  .^(1/2).*zs)+(sqrt(-1)*(-2)).*alpha.^2.*eta1.*eta4.^(3/2).*eta6.*h.* ...
  k.^2.*nu.*phi.*psi.*besselj(0,sqrt(-1).*delta.*eta4.^(-1/2).*((sqrt(-1)* ...
  (-1)).*eta3+eta4.*k.^2).^(1/2)).*bessely(0,(sqrt(-1)*(-1)).*delta.* ...
  eta4.^(-1/2).*((sqrt(-1)*(-1)).*eta3+eta4.*k.^2).^(1/2).*zs)+(-1).* ...
  alpha.^2.*eta2.*eta3.*eta4.^(1/2).*eta6.*h.*pvRi.*besselj(0,sqrt(-1).* ...
  delta.*eta4.^(-1/2).*((sqrt(-1)*(-1)).*eta3+eta4.*k.^2).^(1/2)).* ...
  bessely(0,(sqrt(-1)*(-1)).*delta.*eta4.^(-1/2).*((sqrt(-1)*(-1)).*eta3+ ...
  eta4.*k.^2).^(1/2).*zs)+(sqrt(-1)*(-1)).*alpha.^2.*eta2.*eta4.^(3/2).* ...
  eta6.*h.*k.^2.*pvRi.*besselj(0,sqrt(-1).*delta.*eta4.^(-1/2).*((sqrt(-1) ...
  *(-1)).*eta3+eta4.*k.^2).^(1/2)).*bessely(0,(sqrt(-1)*(-1)).*delta.* ...
  eta4.^(-1/2).*((sqrt(-1)*(-1)).*eta3+eta4.*k.^2).^(1/2).*zs)+alpha.^2.* ...
  eta2.*eta3.*eta4.^(1/2).*eta6.*h.*phi.*pvRi.*besselj(0,sqrt(-1).*delta.* ...
  eta4.^(-1/2).*((sqrt(-1)*(-1)).*eta3+eta4.*k.^2).^(1/2)).*bessely(0,( ...
  sqrt(-1)*(-1)).*delta.*eta4.^(-1/2).*((sqrt(-1)*(-1)).*eta3+eta4.*k.^2) ...
  .^(1/2).*zs)+sqrt(-1).*alpha.^2.*eta2.*eta4.^(3/2).*eta6.*h.*k.^2.*phi.* ...
  pvRi.*besselj(0,sqrt(-1).*delta.*eta4.^(-1/2).*((sqrt(-1)*(-1)).*eta3+ ...
  eta4.*k.^2).^(1/2)).*bessely(0,(sqrt(-1)*(-1)).*delta.*eta4.^(-1/2).*(( ...
  sqrt(-1)*(-1)).*eta3+eta4.*k.^2).^(1/2).*zs)+(sqrt(-1)*(-1)).*alpha.^2.* ...
  delta.*eta2.*eta3.*eta4.^(1/2).*h.*Pcs.*Rey.*vr0.*besselj(0,sqrt(-1).* ...
  delta.*eta4.^(-1/2).*((sqrt(-1)*(-1)).*eta3+eta4.*k.^2).^(1/2)).* ...
  bessely(0,(sqrt(-1)*(-1)).*delta.*eta4.^(-1/2).*((sqrt(-1)*(-1)).*eta3+ ...
  eta4.*k.^2).^(1/2).*zs)+alpha.^2.*delta.*eta2.*eta4.^(3/2).*h.*k.^2.* ...
  Pcs.*Rey.*vr0.*besselj(0,sqrt(-1).*delta.*eta4.^(-1/2).*((sqrt(-1)*(-1)) ...
  .*eta3+eta4.*k.^2).^(1/2)).*bessely(0,(sqrt(-1)*(-1)).*delta.*eta4.^( ...
  -1/2).*((sqrt(-1)*(-1)).*eta3+eta4.*k.^2).^(1/2).*zs)+sqrt(-1).*alpha.* ...
  delta.*eta2.*eta3.*eta4.^(1/2).*h.*Pes.*Rey.*vr0.*besselj(0,sqrt(-1).* ...
  delta.*eta4.^(-1/2).*((sqrt(-1)*(-1)).*eta3+eta4.*k.^2).^(1/2)).* ...
  bessely(0,(sqrt(-1)*(-1)).*delta.*eta4.^(-1/2).*((sqrt(-1)*(-1)).*eta3+ ...
  eta4.*k.^2).^(1/2).*zs)+(sqrt(-1)*(-1)).*alpha.^2.*delta.*eta2.*eta3.* ...
  eta4.^(1/2).*h.*Pes.*Rey.*vr0.*besselj(0,sqrt(-1).*delta.*eta4.^(-1/2).* ...
  ((sqrt(-1)*(-1)).*eta3+eta4.*k.^2).^(1/2)).*bessely(0,(sqrt(-1)*(-1)).* ...
  delta.*eta4.^(-1/2).*((sqrt(-1)*(-1)).*eta3+eta4.*k.^2).^(1/2).*zs)+(-1) ...
  .*alpha.*delta.*eta2.*eta4.^(3/2).*h.*k.^2.*Pes.*Rey.*vr0.*besselj(0, ...
  sqrt(-1).*delta.*eta4.^(-1/2).*((sqrt(-1)*(-1)).*eta3+eta4.*k.^2).^(1/2) ...
  ).*bessely(0,(sqrt(-1)*(-1)).*delta.*eta4.^(-1/2).*((sqrt(-1)*(-1)).* ...
  eta3+eta4.*k.^2).^(1/2).*zs)+alpha.^2.*delta.*eta2.*eta4.^(3/2).*h.* ...
  k.^2.*Pes.*Rey.*vr0.*besselj(0,sqrt(-1).*delta.*eta4.^(-1/2).*((sqrt(-1) ...
  *(-1)).*eta3+eta4.*k.^2).^(1/2)).*bessely(0,(sqrt(-1)*(-1)).*delta.* ...
  eta4.^(-1/2).*((sqrt(-1)*(-1)).*eta3+eta4.*k.^2).^(1/2).*zs)+(sqrt(-1)*( ...
  -1)).*alpha.^2.*delta.*eta2.*eta3.*eta4.^(1/2).*h.*Pvs.*Rey.*vr0.* ...
  besselj(0,sqrt(-1).*delta.*eta4.^(-1/2).*((sqrt(-1)*(-1)).*eta3+eta4.* ...
  k.^2).^(1/2)).*bessely(0,(sqrt(-1)*(-1)).*delta.*eta4.^(-1/2).*((sqrt( ...
  -1)*(-1)).*eta3+eta4.*k.^2).^(1/2).*zs)+alpha.^2.*delta.*eta2.*eta4.^( ...
  3/2).*h.*k.^2.*Pvs.*Rey.*vr0.*besselj(0,sqrt(-1).*delta.*eta4.^(-1/2).*( ...
  (sqrt(-1)*(-1)).*eta3+eta4.*k.^2).^(1/2)).*bessely(0,(sqrt(-1)*(-1)).* ...
  delta.*eta4.^(-1/2).*((sqrt(-1)*(-1)).*eta3+eta4.*k.^2).^(1/2).*zs)+2.* ...
  alpha.^2.*delta.^2.*dvr0.*eta3.*eta5.*((sqrt(-1)*(-1)).*eta3+eta4.*k.^2) ...
  .^(1/2).*Pcs.*phi.*besselj(1,sqrt(-1).*delta.*eta4.^(-1/2).*((sqrt(-1)*( ...
  -1)).*eta3+eta4.*k.^2).^(1/2)).*bessely(0,(sqrt(-1)*(-1)).*delta.* ...
  eta4.^(-1/2).*((sqrt(-1)*(-1)).*eta3+eta4.*k.^2).^(1/2).*zs)+(sqrt(-1)* ...
  2).*alpha.^2.*delta.^2.*dvr0.*eta4.*eta5.*k.^2.*((sqrt(-1)*(-1)).*eta3+ ...
  eta4.*k.^2).^(1/2).*Pcs.*phi.*besselj(1,sqrt(-1).*delta.*eta4.^(-1/2).*( ...
  (sqrt(-1)*(-1)).*eta3+eta4.*k.^2).^(1/2)).*bessely(0,(sqrt(-1)*(-1)).* ...
  delta.*eta4.^(-1/2).*((sqrt(-1)*(-1)).*eta3+eta4.*k.^2).^(1/2).*zs)+(-1) ...
  .*alpha.*delta.*eta2.*eta3.*h.*((sqrt(-1)*(-1)).*eta3+eta4.*k.^2).^(1/2) ...
  .*P0.*Pcs.*phi.*besselj(1,sqrt(-1).*delta.*eta4.^(-1/2).*((sqrt(-1)*(-1) ...
  ).*eta3+eta4.*k.^2).^(1/2)).*bessely(0,(sqrt(-1)*(-1)).*delta.*eta4.^( ...
  -1/2).*((sqrt(-1)*(-1)).*eta3+eta4.*k.^2).^(1/2).*zs)+(sqrt(-1)*(-1)).* ...
  alpha.*delta.*eta2.*eta4.*h.*k.^2.*((sqrt(-1)*(-1)).*eta3+eta4.*k.^2).^( ...
  1/2).*P0.*Pcs.*phi.*besselj(1,sqrt(-1).*delta.*eta4.^(-1/2).*((sqrt(-1)* ...
  (-1)).*eta3+eta4.*k.^2).^(1/2)).*bessely(0,(sqrt(-1)*(-1)).*delta.* ...
  eta4.^(-1/2).*((sqrt(-1)*(-1)).*eta3+eta4.*k.^2).^(1/2).*zs)+alpha.^2.* ...
  delta.*eta2.*eta3.*h.*((sqrt(-1)*(-1)).*eta3+eta4.*k.^2).^(1/2).*pc1.* ...
  Pcs.*phi.*besselj(1,sqrt(-1).*delta.*eta4.^(-1/2).*((sqrt(-1)*(-1)).* ...
  eta3+eta4.*k.^2).^(1/2)).*bessely(0,(sqrt(-1)*(-1)).*delta.*eta4.^(-1/2) ...
  .*((sqrt(-1)*(-1)).*eta3+eta4.*k.^2).^(1/2).*zs)+sqrt(-1).*alpha.^2.* ...
  delta.*eta2.*eta4.*h.*k.^2.*((sqrt(-1)*(-1)).*eta3+eta4.*k.^2).^(1/2).* ...
  pc1.*Pcs.*phi.*besselj(1,sqrt(-1).*delta.*eta4.^(-1/2).*((sqrt(-1)*(-1)) ...
  .*eta3+eta4.*k.^2).^(1/2)).*bessely(0,(sqrt(-1)*(-1)).*delta.*eta4.^( ...
  -1/2).*((sqrt(-1)*(-1)).*eta3+eta4.*k.^2).^(1/2).*zs)+alpha.^2.*delta.* ...
  eta2.*eta3.*((sqrt(-1)*(-1)).*eta3+eta4.*k.^2).^(1/2).*pcRi.*Pcs.*phi.* ...
  besselj(1,sqrt(-1).*delta.*eta4.^(-1/2).*((sqrt(-1)*(-1)).*eta3+eta4.* ...
  k.^2).^(1/2)).*bessely(0,(sqrt(-1)*(-1)).*delta.*eta4.^(-1/2).*((sqrt( ...
  -1)*(-1)).*eta3+eta4.*k.^2).^(1/2).*zs)+(-1).*alpha.^2.*delta.*eta2.* ...
  eta3.*h.*((sqrt(-1)*(-1)).*eta3+eta4.*k.^2).^(1/2).*pcRi.*Pcs.*phi.* ...
  besselj(1,sqrt(-1).*delta.*eta4.^(-1/2).*((sqrt(-1)*(-1)).*eta3+eta4.* ...
  k.^2).^(1/2)).*bessely(0,(sqrt(-1)*(-1)).*delta.*eta4.^(-1/2).*((sqrt( ...
  -1)*(-1)).*eta3+eta4.*k.^2).^(1/2).*zs)+sqrt(-1).*alpha.^2.*delta.* ...
  eta2.*eta4.*k.^2.*((sqrt(-1)*(-1)).*eta3+eta4.*k.^2).^(1/2).*pcRi.*Pcs.* ...
  phi.*besselj(1,sqrt(-1).*delta.*eta4.^(-1/2).*((sqrt(-1)*(-1)).*eta3+ ...
  eta4.*k.^2).^(1/2)).*bessely(0,(sqrt(-1)*(-1)).*delta.*eta4.^(-1/2).*(( ...
  sqrt(-1)*(-1)).*eta3+eta4.*k.^2).^(1/2).*zs)+(sqrt(-1)*(-1)).*alpha.^2.* ...
  delta.*eta2.*eta4.*h.*k.^2.*((sqrt(-1)*(-1)).*eta3+eta4.*k.^2).^(1/2).* ...
  pcRi.*Pcs.*phi.*besselj(1,sqrt(-1).*delta.*eta4.^(-1/2).*((sqrt(-1)*(-1) ...
  ).*eta3+eta4.*k.^2).^(1/2)).*bessely(0,(sqrt(-1)*(-1)).*delta.*eta4.^( ...
  -1/2).*((sqrt(-1)*(-1)).*eta3+eta4.*k.^2).^(1/2).*zs)+(-2).*alpha.* ...
  delta.^2.*dvr0.*eta3.*eta5.*((sqrt(-1)*(-1)).*eta3+eta4.*k.^2).^(1/2).* ...
  Pes.*phi.*besselj(1,sqrt(-1).*delta.*eta4.^(-1/2).*((sqrt(-1)*(-1)).* ...
  eta3+eta4.*k.^2).^(1/2)).*bessely(0,(sqrt(-1)*(-1)).*delta.*eta4.^(-1/2) ...
  .*((sqrt(-1)*(-1)).*eta3+eta4.*k.^2).^(1/2).*zs)+2.*alpha.^2.*delta.^2.* ...
  dvr0.*eta3.*eta5.*((sqrt(-1)*(-1)).*eta3+eta4.*k.^2).^(1/2).*Pes.*phi.* ...
  besselj(1,sqrt(-1).*delta.*eta4.^(-1/2).*((sqrt(-1)*(-1)).*eta3+eta4.* ...
  k.^2).^(1/2)).*bessely(0,(sqrt(-1)*(-1)).*delta.*eta4.^(-1/2).*((sqrt( ...
  -1)*(-1)).*eta3+eta4.*k.^2).^(1/2).*zs)+(sqrt(-1)*(-2)).*alpha.* ...
  delta.^2.*dvr0.*eta4.*eta5.*k.^2.*((sqrt(-1)*(-1)).*eta3+eta4.*k.^2).^( ...
  1/2).*Pes.*phi.*besselj(1,sqrt(-1).*delta.*eta4.^(-1/2).*((sqrt(-1)*(-1) ...
  ).*eta3+eta4.*k.^2).^(1/2)).*bessely(0,(sqrt(-1)*(-1)).*delta.*eta4.^( ...
  -1/2).*((sqrt(-1)*(-1)).*eta3+eta4.*k.^2).^(1/2).*zs)+(sqrt(-1)*2).* ...
  alpha.^2.*delta.^2.*dvr0.*eta4.*eta5.*k.^2.*((sqrt(-1)*(-1)).*eta3+ ...
  eta4.*k.^2).^(1/2).*Pes.*phi.*besselj(1,sqrt(-1).*delta.*eta4.^(-1/2).*( ...
  (sqrt(-1)*(-1)).*eta3+eta4.*k.^2).^(1/2)).*bessely(0,(sqrt(-1)*(-1)).* ...
  delta.*eta4.^(-1/2).*((sqrt(-1)*(-1)).*eta3+eta4.*k.^2).^(1/2).*zs)+ ...
  delta.*eta2.*eta3.*h.*((sqrt(-1)*(-1)).*eta3+eta4.*k.^2).^(1/2).*P0.* ...
  Pes.*phi.*besselj(1,sqrt(-1).*delta.*eta4.^(-1/2).*((sqrt(-1)*(-1)).* ...
  eta3+eta4.*k.^2).^(1/2)).*bessely(0,(sqrt(-1)*(-1)).*delta.*eta4.^(-1/2) ...
  .*((sqrt(-1)*(-1)).*eta3+eta4.*k.^2).^(1/2).*zs)+(-1).*alpha.*delta.* ...
  eta2.*eta3.*h.*((sqrt(-1)*(-1)).*eta3+eta4.*k.^2).^(1/2).*P0.*Pes.*phi.* ...
  besselj(1,sqrt(-1).*delta.*eta4.^(-1/2).*((sqrt(-1)*(-1)).*eta3+eta4.* ...
  k.^2).^(1/2)).*bessely(0,(sqrt(-1)*(-1)).*delta.*eta4.^(-1/2).*((sqrt( ...
  -1)*(-1)).*eta3+eta4.*k.^2).^(1/2).*zs)+sqrt(-1).*delta.*eta2.*eta4.*h.* ...
  k.^2.*((sqrt(-1)*(-1)).*eta3+eta4.*k.^2).^(1/2).*P0.*Pes.*phi.*besselj( ...
  1,sqrt(-1).*delta.*eta4.^(-1/2).*((sqrt(-1)*(-1)).*eta3+eta4.*k.^2).^( ...
  1/2)).*bessely(0,(sqrt(-1)*(-1)).*delta.*eta4.^(-1/2).*((sqrt(-1)*(-1)) ...
  .*eta3+eta4.*k.^2).^(1/2).*zs)+(sqrt(-1)*(-1)).*alpha.*delta.*eta2.* ...
  eta4.*h.*k.^2.*((sqrt(-1)*(-1)).*eta3+eta4.*k.^2).^(1/2).*P0.*Pes.*phi.* ...
  besselj(1,sqrt(-1).*delta.*eta4.^(-1/2).*((sqrt(-1)*(-1)).*eta3+eta4.* ...
  k.^2).^(1/2)).*bessely(0,(sqrt(-1)*(-1)).*delta.*eta4.^(-1/2).*((sqrt( ...
  -1)*(-1)).*eta3+eta4.*k.^2).^(1/2).*zs)+(-1).*alpha.*delta.*eta2.*eta3.* ...
  h.*((sqrt(-1)*(-1)).*eta3+eta4.*k.^2).^(1/2).*pc1.*Pes.*phi.*besselj(1, ...
  sqrt(-1).*delta.*eta4.^(-1/2).*((sqrt(-1)*(-1)).*eta3+eta4.*k.^2).^(1/2) ...
  ).*bessely(0,(sqrt(-1)*(-1)).*delta.*eta4.^(-1/2).*((sqrt(-1)*(-1)).* ...
  eta3+eta4.*k.^2).^(1/2).*zs)+alpha.^2.*delta.*eta2.*eta3.*h.*((sqrt(-1)* ...
  (-1)).*eta3+eta4.*k.^2).^(1/2).*pc1.*Pes.*phi.*besselj(1,sqrt(-1).* ...
  delta.*eta4.^(-1/2).*((sqrt(-1)*(-1)).*eta3+eta4.*k.^2).^(1/2)).* ...
  bessely(0,(sqrt(-1)*(-1)).*delta.*eta4.^(-1/2).*((sqrt(-1)*(-1)).*eta3+ ...
  eta4.*k.^2).^(1/2).*zs)+(sqrt(-1)*(-1)).*alpha.*delta.*eta2.*eta4.*h.* ...
  k.^2.*((sqrt(-1)*(-1)).*eta3+eta4.*k.^2).^(1/2).*pc1.*Pes.*phi.*besselj( ...
  1,sqrt(-1).*delta.*eta4.^(-1/2).*((sqrt(-1)*(-1)).*eta3+eta4.*k.^2).^( ...
  1/2)).*bessely(0,(sqrt(-1)*(-1)).*delta.*eta4.^(-1/2).*((sqrt(-1)*(-1)) ...
  .*eta3+eta4.*k.^2).^(1/2).*zs)+sqrt(-1).*alpha.^2.*delta.*eta2.*eta4.* ...
  h.*k.^2.*((sqrt(-1)*(-1)).*eta3+eta4.*k.^2).^(1/2).*pc1.*Pes.*phi.* ...
  besselj(1,sqrt(-1).*delta.*eta4.^(-1/2).*((sqrt(-1)*(-1)).*eta3+eta4.* ...
  k.^2).^(1/2)).*bessely(0,(sqrt(-1)*(-1)).*delta.*eta4.^(-1/2).*((sqrt( ...
  -1)*(-1)).*eta3+eta4.*k.^2).^(1/2).*zs)+(-1).*alpha.*delta.*eta2.*eta3.* ...
  ((sqrt(-1)*(-1)).*eta3+eta4.*k.^2).^(1/2).*pcRi.*Pes.*phi.*besselj(1, ...
  sqrt(-1).*delta.*eta4.^(-1/2).*((sqrt(-1)*(-1)).*eta3+eta4.*k.^2).^(1/2) ...
  ).*bessely(0,(sqrt(-1)*(-1)).*delta.*eta4.^(-1/2).*((sqrt(-1)*(-1)).* ...
  eta3+eta4.*k.^2).^(1/2).*zs)+alpha.^2.*delta.*eta2.*eta3.*((sqrt(-1)*( ...
  -1)).*eta3+eta4.*k.^2).^(1/2).*pcRi.*Pes.*phi.*besselj(1,sqrt(-1).* ...
  delta.*eta4.^(-1/2).*((sqrt(-1)*(-1)).*eta3+eta4.*k.^2).^(1/2)).* ...
  bessely(0,(sqrt(-1)*(-1)).*delta.*eta4.^(-1/2).*((sqrt(-1)*(-1)).*eta3+ ...
  eta4.*k.^2).^(1/2).*zs)+alpha.*delta.*eta2.*eta3.*h.*((sqrt(-1)*(-1)).* ...
  eta3+eta4.*k.^2).^(1/2).*pcRi.*Pes.*phi.*besselj(1,sqrt(-1).*delta.* ...
  eta4.^(-1/2).*((sqrt(-1)*(-1)).*eta3+eta4.*k.^2).^(1/2)).*bessely(0,( ...
  sqrt(-1)*(-1)).*delta.*eta4.^(-1/2).*((sqrt(-1)*(-1)).*eta3+eta4.*k.^2) ...
  .^(1/2).*zs)+(-1).*alpha.^2.*delta.*eta2.*eta3.*h.*((sqrt(-1)*(-1)).* ...
  eta3+eta4.*k.^2).^(1/2).*pcRi.*Pes.*phi.*besselj(1,sqrt(-1).*delta.* ...
  eta4.^(-1/2).*((sqrt(-1)*(-1)).*eta3+eta4.*k.^2).^(1/2)).*bessely(0,( ...
  sqrt(-1)*(-1)).*delta.*eta4.^(-1/2).*((sqrt(-1)*(-1)).*eta3+eta4.*k.^2) ...
  .^(1/2).*zs)+(sqrt(-1)*(-1)).*alpha.*delta.*eta2.*eta4.*k.^2.*((sqrt(-1) ...
  *(-1)).*eta3+eta4.*k.^2).^(1/2).*pcRi.*Pes.*phi.*besselj(1,sqrt(-1).* ...
  delta.*eta4.^(-1/2).*((sqrt(-1)*(-1)).*eta3+eta4.*k.^2).^(1/2)).* ...
  bessely(0,(sqrt(-1)*(-1)).*delta.*eta4.^(-1/2).*((sqrt(-1)*(-1)).*eta3+ ...
  eta4.*k.^2).^(1/2).*zs)+sqrt(-1).*alpha.^2.*delta.*eta2.*eta4.*k.^2.*(( ...
  sqrt(-1)*(-1)).*eta3+eta4.*k.^2).^(1/2).*pcRi.*Pes.*phi.*besselj(1,sqrt( ...
  -1).*delta.*eta4.^(-1/2).*((sqrt(-1)*(-1)).*eta3+eta4.*k.^2).^(1/2)).* ...
  bessely(0,(sqrt(-1)*(-1)).*delta.*eta4.^(-1/2).*((sqrt(-1)*(-1)).*eta3+ ...
  eta4.*k.^2).^(1/2).*zs)+sqrt(-1).*alpha.*delta.*eta2.*eta4.*h.*k.^2.*(( ...
  sqrt(-1)*(-1)).*eta3+eta4.*k.^2).^(1/2).*pcRi.*Pes.*phi.*besselj(1,sqrt( ...
  -1).*delta.*eta4.^(-1/2).*((sqrt(-1)*(-1)).*eta3+eta4.*k.^2).^(1/2)).* ...
  bessely(0,(sqrt(-1)*(-1)).*delta.*eta4.^(-1/2).*((sqrt(-1)*(-1)).*eta3+ ...
  eta4.*k.^2).^(1/2).*zs)+(sqrt(-1)*(-1)).*alpha.^2.*delta.*eta2.*eta4.* ...
  h.*k.^2.*((sqrt(-1)*(-1)).*eta3+eta4.*k.^2).^(1/2).*pcRi.*Pes.*phi.* ...
  besselj(1,sqrt(-1).*delta.*eta4.^(-1/2).*((sqrt(-1)*(-1)).*eta3+eta4.* ...
  k.^2).^(1/2)).*bessely(0,(sqrt(-1)*(-1)).*delta.*eta4.^(-1/2).*((sqrt( ...
  -1)*(-1)).*eta3+eta4.*k.^2).^(1/2).*zs)+(-2).*alpha.^3.*delta.^2.*eta2.* ...
  ((sqrt(-1)*(-1)).*eta3+eta4.*k.^2).^(1/2).*Pcs.*phi.*psi.*besselj(1, ...
  sqrt(-1).*delta.*eta4.^(-1/2).*((sqrt(-1)*(-1)).*eta3+eta4.*k.^2).^(1/2) ...
  ).*bessely(0,(sqrt(-1)*(-1)).*delta.*eta4.^(-1/2).*((sqrt(-1)*(-1)).* ...
  eta3+eta4.*k.^2).^(1/2).*zs)+(-2).*alpha.^2.*delta.^2.*eta3.*((sqrt(-1)* ...
  (-1)).*eta3+eta4.*k.^2).^(1/2).*Pcs.*phi.*psi.*besselj(1,sqrt(-1).* ...
  delta.*eta4.^(-1/2).*((sqrt(-1)*(-1)).*eta3+eta4.*k.^2).^(1/2)).* ...
  bessely(0,(sqrt(-1)*(-1)).*delta.*eta4.^(-1/2).*((sqrt(-1)*(-1)).*eta3+ ...
  eta4.*k.^2).^(1/2).*zs)+(sqrt(-1)*(-2)).*alpha.^2.*delta.^2.*eta4.* ...
  k.^2.*((sqrt(-1)*(-1)).*eta3+eta4.*k.^2).^(1/2).*Pcs.*phi.*psi.*besselj( ...
  1,sqrt(-1).*delta.*eta4.^(-1/2).*((sqrt(-1)*(-1)).*eta3+eta4.*k.^2).^( ...
  1/2)).*bessely(0,(sqrt(-1)*(-1)).*delta.*eta4.^(-1/2).*((sqrt(-1)*(-1)) ...
  .*eta3+eta4.*k.^2).^(1/2).*zs)+(-2).*alpha.^2.*delta.*eta1.*eta3.*(( ...
  sqrt(-1)*(-1)).*eta3+eta4.*k.^2).^(1/2).*nu.*Pcs.*phi.*psi.*besselj(1, ...
  sqrt(-1).*delta.*eta4.^(-1/2).*((sqrt(-1)*(-1)).*eta3+eta4.*k.^2).^(1/2) ...
  ).*bessely(0,(sqrt(-1)*(-1)).*delta.*eta4.^(-1/2).*((sqrt(-1)*(-1)).* ...
  eta3+eta4.*k.^2).^(1/2).*zs)+(-2).*alpha.^2.*delta.*eta1.*eta3.*h.*(( ...
  sqrt(-1)*(-1)).*eta3+eta4.*k.^2).^(1/2).*nu.*Pcs.*phi.*psi.*besselj(1, ...
  sqrt(-1).*delta.*eta4.^(-1/2).*((sqrt(-1)*(-1)).*eta3+eta4.*k.^2).^(1/2) ...
  ).*bessely(0,(sqrt(-1)*(-1)).*delta.*eta4.^(-1/2).*((sqrt(-1)*(-1)).* ...
  eta3+eta4.*k.^2).^(1/2).*zs)+(sqrt(-1)*(-2)).*alpha.^2.*delta.*eta1.* ...
  eta4.*k.^2.*((sqrt(-1)*(-1)).*eta3+eta4.*k.^2).^(1/2).*nu.*Pcs.*phi.* ...
  psi.*besselj(1,sqrt(-1).*delta.*eta4.^(-1/2).*((sqrt(-1)*(-1)).*eta3+ ...
  eta4.*k.^2).^(1/2)).*bessely(0,(sqrt(-1)*(-1)).*delta.*eta4.^(-1/2).*(( ...
  sqrt(-1)*(-1)).*eta3+eta4.*k.^2).^(1/2).*zs)+(sqrt(-1)*(-2)).*alpha.^2.* ...
  delta.*eta1.*eta4.*h.*k.^2.*((sqrt(-1)*(-1)).*eta3+eta4.*k.^2).^(1/2).* ...
  nu.*Pcs.*phi.*psi.*besselj(1,sqrt(-1).*delta.*eta4.^(-1/2).*((sqrt(-1)*( ...
  -1)).*eta3+eta4.*k.^2).^(1/2)).*bessely(0,(sqrt(-1)*(-1)).*delta.* ...
  eta4.^(-1/2).*((sqrt(-1)*(-1)).*eta3+eta4.*k.^2).^(1/2).*zs)+2.* ...
  alpha.^2.*delta.^2.*eta2.*((sqrt(-1)*(-1)).*eta3+eta4.*k.^2).^(1/2).* ...
  Pes.*phi.*psi.*besselj(1,sqrt(-1).*delta.*eta4.^(-1/2).*((sqrt(-1)*(-1)) ...
  .*eta3+eta4.*k.^2).^(1/2)).*bessely(0,(sqrt(-1)*(-1)).*delta.*eta4.^( ...
  -1/2).*((sqrt(-1)*(-1)).*eta3+eta4.*k.^2).^(1/2).*zs)+(-2).*alpha.^3.* ...
  delta.^2.*eta2.*((sqrt(-1)*(-1)).*eta3+eta4.*k.^2).^(1/2).*Pes.*phi.* ...
  psi.*besselj(1,sqrt(-1).*delta.*eta4.^(-1/2).*((sqrt(-1)*(-1)).*eta3+ ...
  eta4.*k.^2).^(1/2)).*bessely(0,(sqrt(-1)*(-1)).*delta.*eta4.^(-1/2).*(( ...
  sqrt(-1)*(-1)).*eta3+eta4.*k.^2).^(1/2).*zs)+2.*alpha.*delta.^2.*eta3.*( ...
  (sqrt(-1)*(-1)).*eta3+eta4.*k.^2).^(1/2).*Pes.*phi.*psi.*besselj(1,sqrt( ...
  -1).*delta.*eta4.^(-1/2).*((sqrt(-1)*(-1)).*eta3+eta4.*k.^2).^(1/2)).* ...
  bessely(0,(sqrt(-1)*(-1)).*delta.*eta4.^(-1/2).*((sqrt(-1)*(-1)).*eta3+ ...
  eta4.*k.^2).^(1/2).*zs)+(-2).*alpha.^2.*delta.^2.*eta3.*((sqrt(-1)*(-1)) ...
  .*eta3+eta4.*k.^2).^(1/2).*Pes.*phi.*psi.*besselj(1,sqrt(-1).*delta.* ...
  eta4.^(-1/2).*((sqrt(-1)*(-1)).*eta3+eta4.*k.^2).^(1/2)).*bessely(0,( ...
  sqrt(-1)*(-1)).*delta.*eta4.^(-1/2).*((sqrt(-1)*(-1)).*eta3+eta4.*k.^2) ...
  .^(1/2).*zs)+(sqrt(-1)*2).*alpha.*delta.^2.*eta4.*k.^2.*((sqrt(-1)*(-1)) ...
  .*eta3+eta4.*k.^2).^(1/2).*Pes.*phi.*psi.*besselj(1,sqrt(-1).*delta.* ...
  eta4.^(-1/2).*((sqrt(-1)*(-1)).*eta3+eta4.*k.^2).^(1/2)).*bessely(0,( ...
  sqrt(-1)*(-1)).*delta.*eta4.^(-1/2).*((sqrt(-1)*(-1)).*eta3+eta4.*k.^2) ...
  .^(1/2).*zs)+(sqrt(-1)*(-2)).*alpha.^2.*delta.^2.*eta4.*k.^2.*((sqrt(-1) ...
  *(-1)).*eta3+eta4.*k.^2).^(1/2).*Pes.*phi.*psi.*besselj(1,sqrt(-1).* ...
  delta.*eta4.^(-1/2).*((sqrt(-1)*(-1)).*eta3+eta4.*k.^2).^(1/2)).* ...
  bessely(0,(sqrt(-1)*(-1)).*delta.*eta4.^(-1/2).*((sqrt(-1)*(-1)).*eta3+ ...
  eta4.*k.^2).^(1/2).*zs)+2.*alpha.*delta.*eta1.*eta3.*((sqrt(-1)*(-1)).* ...
  eta3+eta4.*k.^2).^(1/2).*nu.*Pes.*phi.*psi.*besselj(1,sqrt(-1).*delta.* ...
  eta4.^(-1/2).*((sqrt(-1)*(-1)).*eta3+eta4.*k.^2).^(1/2)).*bessely(0,( ...
  sqrt(-1)*(-1)).*delta.*eta4.^(-1/2).*((sqrt(-1)*(-1)).*eta3+eta4.*k.^2) ...
  .^(1/2).*zs)+(-2).*alpha.^2.*delta.*eta1.*eta3.*((sqrt(-1)*(-1)).*eta3+ ...
  eta4.*k.^2).^(1/2).*nu.*Pes.*phi.*psi.*besselj(1,sqrt(-1).*delta.* ...
  eta4.^(-1/2).*((sqrt(-1)*(-1)).*eta3+eta4.*k.^2).^(1/2)).*bessely(0,( ...
  sqrt(-1)*(-1)).*delta.*eta4.^(-1/2).*((sqrt(-1)*(-1)).*eta3+eta4.*k.^2) ...
  .^(1/2).*zs)+2.*alpha.*delta.*eta1.*eta3.*h.*((sqrt(-1)*(-1)).*eta3+ ...
  eta4.*k.^2).^(1/2).*nu.*Pes.*phi.*psi.*besselj(1,sqrt(-1).*delta.* ...
  eta4.^(-1/2).*((sqrt(-1)*(-1)).*eta3+eta4.*k.^2).^(1/2)).*bessely(0,( ...
  sqrt(-1)*(-1)).*delta.*eta4.^(-1/2).*((sqrt(-1)*(-1)).*eta3+eta4.*k.^2) ...
  .^(1/2).*zs)+(-2).*alpha.^2.*delta.*eta1.*eta3.*h.*((sqrt(-1)*(-1)).* ...
  eta3+eta4.*k.^2).^(1/2).*nu.*Pes.*phi.*psi.*besselj(1,sqrt(-1).*delta.* ...
  eta4.^(-1/2).*((sqrt(-1)*(-1)).*eta3+eta4.*k.^2).^(1/2)).*bessely(0,( ...
  sqrt(-1)*(-1)).*delta.*eta4.^(-1/2).*((sqrt(-1)*(-1)).*eta3+eta4.*k.^2) ...
  .^(1/2).*zs)+(sqrt(-1)*2).*alpha.*delta.*eta1.*eta4.*k.^2.*((sqrt(-1)*( ...
  -1)).*eta3+eta4.*k.^2).^(1/2).*nu.*Pes.*phi.*psi.*besselj(1,sqrt(-1).* ...
  delta.*eta4.^(-1/2).*((sqrt(-1)*(-1)).*eta3+eta4.*k.^2).^(1/2)).* ...
  bessely(0,(sqrt(-1)*(-1)).*delta.*eta4.^(-1/2).*((sqrt(-1)*(-1)).*eta3+ ...
  eta4.*k.^2).^(1/2).*zs)+(sqrt(-1)*(-2)).*alpha.^2.*delta.*eta1.*eta4.* ...
  k.^2.*((sqrt(-1)*(-1)).*eta3+eta4.*k.^2).^(1/2).*nu.*Pes.*phi.*psi.* ...
  besselj(1,sqrt(-1).*delta.*eta4.^(-1/2).*((sqrt(-1)*(-1)).*eta3+eta4.* ...
  k.^2).^(1/2)).*bessely(0,(sqrt(-1)*(-1)).*delta.*eta4.^(-1/2).*((sqrt( ...
  -1)*(-1)).*eta3+eta4.*k.^2).^(1/2).*zs)+(sqrt(-1)*2).*alpha.*delta.* ...
  eta1.*eta4.*h.*k.^2.*((sqrt(-1)*(-1)).*eta3+eta4.*k.^2).^(1/2).*nu.* ...
  Pes.*phi.*psi.*besselj(1,sqrt(-1).*delta.*eta4.^(-1/2).*((sqrt(-1)*(-1)) ...
  .*eta3+eta4.*k.^2).^(1/2)).*bessely(0,(sqrt(-1)*(-1)).*delta.*eta4.^( ...
  -1/2).*((sqrt(-1)*(-1)).*eta3+eta4.*k.^2).^(1/2).*zs)+(sqrt(-1)*(-2)).* ...
  alpha.^2.*delta.*eta1.*eta4.*h.*k.^2.*((sqrt(-1)*(-1)).*eta3+eta4.*k.^2) ...
  .^(1/2).*nu.*Pes.*phi.*psi.*besselj(1,sqrt(-1).*delta.*eta4.^(-1/2).*(( ...
  sqrt(-1)*(-1)).*eta3+eta4.*k.^2).^(1/2)).*bessely(0,(sqrt(-1)*(-1)).* ...
  delta.*eta4.^(-1/2).*((sqrt(-1)*(-1)).*eta3+eta4.*k.^2).^(1/2).*zs)+ ...
  alpha.^2.*delta.*eta2.*eta3.*h.*((sqrt(-1)*(-1)).*eta3+eta4.*k.^2).^( ...
  1/2).*Pcs.*phi.*pv1.*besselj(1,sqrt(-1).*delta.*eta4.^(-1/2).*((sqrt(-1) ...
  *(-1)).*eta3+eta4.*k.^2).^(1/2)).*bessely(0,(sqrt(-1)*(-1)).*delta.* ...
  eta4.^(-1/2).*((sqrt(-1)*(-1)).*eta3+eta4.*k.^2).^(1/2).*zs)+sqrt(-1).* ...
  alpha.^2.*delta.*eta2.*eta4.*h.*k.^2.*((sqrt(-1)*(-1)).*eta3+eta4.*k.^2) ...
  .^(1/2).*Pcs.*phi.*pv1.*besselj(1,sqrt(-1).*delta.*eta4.^(-1/2).*((sqrt( ...
  -1)*(-1)).*eta3+eta4.*k.^2).^(1/2)).*bessely(0,(sqrt(-1)*(-1)).*delta.* ...
  eta4.^(-1/2).*((sqrt(-1)*(-1)).*eta3+eta4.*k.^2).^(1/2).*zs)+(-1).* ...
  alpha.*delta.*eta2.*eta3.*h.*((sqrt(-1)*(-1)).*eta3+eta4.*k.^2).^(1/2).* ...
  Pes.*phi.*pv1.*besselj(1,sqrt(-1).*delta.*eta4.^(-1/2).*((sqrt(-1)*(-1)) ...
  .*eta3+eta4.*k.^2).^(1/2)).*bessely(0,(sqrt(-1)*(-1)).*delta.*eta4.^( ...
  -1/2).*((sqrt(-1)*(-1)).*eta3+eta4.*k.^2).^(1/2).*zs)+alpha.^2.*delta.* ...
  eta2.*eta3.*h.*((sqrt(-1)*(-1)).*eta3+eta4.*k.^2).^(1/2).*Pes.*phi.* ...
  pv1.*besselj(1,sqrt(-1).*delta.*eta4.^(-1/2).*((sqrt(-1)*(-1)).*eta3+ ...
  eta4.*k.^2).^(1/2)).*bessely(0,(sqrt(-1)*(-1)).*delta.*eta4.^(-1/2).*(( ...
  sqrt(-1)*(-1)).*eta3+eta4.*k.^2).^(1/2).*zs)+(sqrt(-1)*(-1)).*alpha.* ...
  delta.*eta2.*eta4.*h.*k.^2.*((sqrt(-1)*(-1)).*eta3+eta4.*k.^2).^(1/2).* ...
  Pes.*phi.*pv1.*besselj(1,sqrt(-1).*delta.*eta4.^(-1/2).*((sqrt(-1)*(-1)) ...
  .*eta3+eta4.*k.^2).^(1/2)).*bessely(0,(sqrt(-1)*(-1)).*delta.*eta4.^( ...
  -1/2).*((sqrt(-1)*(-1)).*eta3+eta4.*k.^2).^(1/2).*zs)+sqrt(-1).* ...
  alpha.^2.*delta.*eta2.*eta4.*h.*k.^2.*((sqrt(-1)*(-1)).*eta3+eta4.*k.^2) ...
  .^(1/2).*Pes.*phi.*pv1.*besselj(1,sqrt(-1).*delta.*eta4.^(-1/2).*((sqrt( ...
  -1)*(-1)).*eta3+eta4.*k.^2).^(1/2)).*bessely(0,(sqrt(-1)*(-1)).*delta.* ...
  eta4.^(-1/2).*((sqrt(-1)*(-1)).*eta3+eta4.*k.^2).^(1/2).*zs)+alpha.^2.* ...
  delta.*eta2.*eta3.*((sqrt(-1)*(-1)).*eta3+eta4.*k.^2).^(1/2).*Pcs.*phi.* ...
  pvRi.*besselj(1,sqrt(-1).*delta.*eta4.^(-1/2).*((sqrt(-1)*(-1)).*eta3+ ...
  eta4.*k.^2).^(1/2)).*bessely(0,(sqrt(-1)*(-1)).*delta.*eta4.^(-1/2).*(( ...
  sqrt(-1)*(-1)).*eta3+eta4.*k.^2).^(1/2).*zs)+(-1).*alpha.^2.*delta.* ...
  eta2.*eta3.*h.*((sqrt(-1)*(-1)).*eta3+eta4.*k.^2).^(1/2).*Pcs.*phi.* ...
  pvRi.*besselj(1,sqrt(-1).*delta.*eta4.^(-1/2).*((sqrt(-1)*(-1)).*eta3+ ...
  eta4.*k.^2).^(1/2)).*bessely(0,(sqrt(-1)*(-1)).*delta.*eta4.^(-1/2).*(( ...
  sqrt(-1)*(-1)).*eta3+eta4.*k.^2).^(1/2).*zs)+sqrt(-1).*alpha.^2.*delta.* ...
  eta2.*eta4.*k.^2.*((sqrt(-1)*(-1)).*eta3+eta4.*k.^2).^(1/2).*Pcs.*phi.* ...
  pvRi.*besselj(1,sqrt(-1).*delta.*eta4.^(-1/2).*((sqrt(-1)*(-1)).*eta3+ ...
  eta4.*k.^2).^(1/2)).*bessely(0,(sqrt(-1)*(-1)).*delta.*eta4.^(-1/2).*(( ...
  sqrt(-1)*(-1)).*eta3+eta4.*k.^2).^(1/2).*zs)+(sqrt(-1)*(-1)).*alpha.^2.* ...
  delta.*eta2.*eta4.*h.*k.^2.*((sqrt(-1)*(-1)).*eta3+eta4.*k.^2).^(1/2).* ...
  Pcs.*phi.*pvRi.*besselj(1,sqrt(-1).*delta.*eta4.^(-1/2).*((sqrt(-1)*(-1) ...
  ).*eta3+eta4.*k.^2).^(1/2)).*bessely(0,(sqrt(-1)*(-1)).*delta.*eta4.^( ...
  -1/2).*((sqrt(-1)*(-1)).*eta3+eta4.*k.^2).^(1/2).*zs)+(-1).*alpha.* ...
  delta.*eta2.*eta3.*((sqrt(-1)*(-1)).*eta3+eta4.*k.^2).^(1/2).*Pes.*phi.* ...
  pvRi.*besselj(1,sqrt(-1).*delta.*eta4.^(-1/2).*((sqrt(-1)*(-1)).*eta3+ ...
  eta4.*k.^2).^(1/2)).*bessely(0,(sqrt(-1)*(-1)).*delta.*eta4.^(-1/2).*(( ...
  sqrt(-1)*(-1)).*eta3+eta4.*k.^2).^(1/2).*zs)+alpha.^2.*delta.*eta2.* ...
  eta3.*((sqrt(-1)*(-1)).*eta3+eta4.*k.^2).^(1/2).*Pes.*phi.*pvRi.* ...
  besselj(1,sqrt(-1).*delta.*eta4.^(-1/2).*((sqrt(-1)*(-1)).*eta3+eta4.* ...
  k.^2).^(1/2)).*bessely(0,(sqrt(-1)*(-1)).*delta.*eta4.^(-1/2).*((sqrt( ...
  -1)*(-1)).*eta3+eta4.*k.^2).^(1/2).*zs)+alpha.*delta.*eta2.*eta3.*h.*(( ...
  sqrt(-1)*(-1)).*eta3+eta4.*k.^2).^(1/2).*Pes.*phi.*pvRi.*besselj(1,sqrt( ...
  -1).*delta.*eta4.^(-1/2).*((sqrt(-1)*(-1)).*eta3+eta4.*k.^2).^(1/2)).* ...
  bessely(0,(sqrt(-1)*(-1)).*delta.*eta4.^(-1/2).*((sqrt(-1)*(-1)).*eta3+ ...
  eta4.*k.^2).^(1/2).*zs)+(-1).*alpha.^2.*delta.*eta2.*eta3.*h.*((sqrt(-1) ...
  *(-1)).*eta3+eta4.*k.^2).^(1/2).*Pes.*phi.*pvRi.*besselj(1,sqrt(-1).* ...
  delta.*eta4.^(-1/2).*((sqrt(-1)*(-1)).*eta3+eta4.*k.^2).^(1/2)).* ...
  bessely(0,(sqrt(-1)*(-1)).*delta.*eta4.^(-1/2).*((sqrt(-1)*(-1)).*eta3+ ...
  eta4.*k.^2).^(1/2).*zs)+(sqrt(-1)*(-1)).*alpha.*delta.*eta2.*eta4.* ...
  k.^2.*((sqrt(-1)*(-1)).*eta3+eta4.*k.^2).^(1/2).*Pes.*phi.*pvRi.* ...
  besselj(1,sqrt(-1).*delta.*eta4.^(-1/2).*((sqrt(-1)*(-1)).*eta3+eta4.* ...
  k.^2).^(1/2)).*bessely(0,(sqrt(-1)*(-1)).*delta.*eta4.^(-1/2).*((sqrt( ...
  -1)*(-1)).*eta3+eta4.*k.^2).^(1/2).*zs)+sqrt(-1).*alpha.^2.*delta.* ...
  eta2.*eta4.*k.^2.*((sqrt(-1)*(-1)).*eta3+eta4.*k.^2).^(1/2).*Pes.*phi.* ...
  pvRi.*besselj(1,sqrt(-1).*delta.*eta4.^(-1/2).*((sqrt(-1)*(-1)).*eta3+ ...
  eta4.*k.^2).^(1/2)).*bessely(0,(sqrt(-1)*(-1)).*delta.*eta4.^(-1/2).*(( ...
  sqrt(-1)*(-1)).*eta3+eta4.*k.^2).^(1/2).*zs)+sqrt(-1).*alpha.*delta.* ...
  eta2.*eta4.*h.*k.^2.*((sqrt(-1)*(-1)).*eta3+eta4.*k.^2).^(1/2).*Pes.* ...
  phi.*pvRi.*besselj(1,sqrt(-1).*delta.*eta4.^(-1/2).*((sqrt(-1)*(-1)).* ...
  eta3+eta4.*k.^2).^(1/2)).*bessely(0,(sqrt(-1)*(-1)).*delta.*eta4.^(-1/2) ...
  .*((sqrt(-1)*(-1)).*eta3+eta4.*k.^2).^(1/2).*zs)+(sqrt(-1)*(-1)).* ...
  alpha.^2.*delta.*eta2.*eta4.*h.*k.^2.*((sqrt(-1)*(-1)).*eta3+eta4.*k.^2) ...
  .^(1/2).*Pes.*phi.*pvRi.*besselj(1,sqrt(-1).*delta.*eta4.^(-1/2).*(( ...
  sqrt(-1)*(-1)).*eta3+eta4.*k.^2).^(1/2)).*bessely(0,(sqrt(-1)*(-1)).* ...
  delta.*eta4.^(-1/2).*((sqrt(-1)*(-1)).*eta3+eta4.*k.^2).^(1/2).*zs)+2.* ...
  alpha.^2.*delta.^2.*dvr0.*eta3.*eta5.*((sqrt(-1)*(-1)).*eta3+eta4.*k.^2) ...
  .^(1/2).*phi.*Pvs.*besselj(1,sqrt(-1).*delta.*eta4.^(-1/2).*((sqrt(-1)*( ...
  -1)).*eta3+eta4.*k.^2).^(1/2)).*bessely(0,(sqrt(-1)*(-1)).*delta.* ...
  eta4.^(-1/2).*((sqrt(-1)*(-1)).*eta3+eta4.*k.^2).^(1/2).*zs)+(sqrt(-1)* ...
  2).*alpha.^2.*delta.^2.*dvr0.*eta4.*eta5.*k.^2.*((sqrt(-1)*(-1)).*eta3+ ...
  eta4.*k.^2).^(1/2).*phi.*Pvs.*besselj(1,sqrt(-1).*delta.*eta4.^(-1/2).*( ...
  (sqrt(-1)*(-1)).*eta3+eta4.*k.^2).^(1/2)).*bessely(0,(sqrt(-1)*(-1)).* ...
  delta.*eta4.^(-1/2).*((sqrt(-1)*(-1)).*eta3+eta4.*k.^2).^(1/2).*zs)+(-1) ...
  .*alpha.*delta.*eta2.*eta3.*h.*((sqrt(-1)*(-1)).*eta3+eta4.*k.^2).^(1/2) ...
  .*P0.*phi.*Pvs.*besselj(1,sqrt(-1).*delta.*eta4.^(-1/2).*((sqrt(-1)*(-1) ...
  ).*eta3+eta4.*k.^2).^(1/2)).*bessely(0,(sqrt(-1)*(-1)).*delta.*eta4.^( ...
  -1/2).*((sqrt(-1)*(-1)).*eta3+eta4.*k.^2).^(1/2).*zs)+(sqrt(-1)*(-1)).* ...
  alpha.*delta.*eta2.*eta4.*h.*k.^2.*((sqrt(-1)*(-1)).*eta3+eta4.*k.^2).^( ...
  1/2).*P0.*phi.*Pvs.*besselj(1,sqrt(-1).*delta.*eta4.^(-1/2).*((sqrt(-1)* ...
  (-1)).*eta3+eta4.*k.^2).^(1/2)).*bessely(0,(sqrt(-1)*(-1)).*delta.* ...
  eta4.^(-1/2).*((sqrt(-1)*(-1)).*eta3+eta4.*k.^2).^(1/2).*zs)+alpha.^2.* ...
  delta.*eta2.*eta3.*h.*((sqrt(-1)*(-1)).*eta3+eta4.*k.^2).^(1/2).*pc1.* ...
  phi.*Pvs.*besselj(1,sqrt(-1).*delta.*eta4.^(-1/2).*((sqrt(-1)*(-1)).* ...
  eta3+eta4.*k.^2).^(1/2)).*bessely(0,(sqrt(-1)*(-1)).*delta.*eta4.^(-1/2) ...
  .*((sqrt(-1)*(-1)).*eta3+eta4.*k.^2).^(1/2).*zs)+sqrt(-1).*alpha.^2.* ...
  delta.*eta2.*eta4.*h.*k.^2.*((sqrt(-1)*(-1)).*eta3+eta4.*k.^2).^(1/2).* ...
  pc1.*phi.*Pvs.*besselj(1,sqrt(-1).*delta.*eta4.^(-1/2).*((sqrt(-1)*(-1)) ...
  .*eta3+eta4.*k.^2).^(1/2)).*bessely(0,(sqrt(-1)*(-1)).*delta.*eta4.^( ...
  -1/2).*((sqrt(-1)*(-1)).*eta3+eta4.*k.^2).^(1/2).*zs)+alpha.^2.*delta.* ...
  eta2.*eta3.*((sqrt(-1)*(-1)).*eta3+eta4.*k.^2).^(1/2).*pcRi.*phi.*Pvs.* ...
  besselj(1,sqrt(-1).*delta.*eta4.^(-1/2).*((sqrt(-1)*(-1)).*eta3+eta4.* ...
  k.^2).^(1/2)).*bessely(0,(sqrt(-1)*(-1)).*delta.*eta4.^(-1/2).*((sqrt( ...
  -1)*(-1)).*eta3+eta4.*k.^2).^(1/2).*zs)+(-1).*alpha.^2.*delta.*eta2.* ...
  eta3.*h.*((sqrt(-1)*(-1)).*eta3+eta4.*k.^2).^(1/2).*pcRi.*phi.*Pvs.* ...
  besselj(1,sqrt(-1).*delta.*eta4.^(-1/2).*((sqrt(-1)*(-1)).*eta3+eta4.* ...
  k.^2).^(1/2)).*bessely(0,(sqrt(-1)*(-1)).*delta.*eta4.^(-1/2).*((sqrt( ...
  -1)*(-1)).*eta3+eta4.*k.^2).^(1/2).*zs)+sqrt(-1).*alpha.^2.*delta.* ...
  eta2.*eta4.*k.^2.*((sqrt(-1)*(-1)).*eta3+eta4.*k.^2).^(1/2).*pcRi.*phi.* ...
  Pvs.*besselj(1,sqrt(-1).*delta.*eta4.^(-1/2).*((sqrt(-1)*(-1)).*eta3+ ...
  eta4.*k.^2).^(1/2)).*bessely(0,(sqrt(-1)*(-1)).*delta.*eta4.^(-1/2).*(( ...
  sqrt(-1)*(-1)).*eta3+eta4.*k.^2).^(1/2).*zs)+(sqrt(-1)*(-1)).*alpha.^2.* ...
  delta.*eta2.*eta4.*h.*k.^2.*((sqrt(-1)*(-1)).*eta3+eta4.*k.^2).^(1/2).* ...
  pcRi.*phi.*Pvs.*besselj(1,sqrt(-1).*delta.*eta4.^(-1/2).*((sqrt(-1)*(-1) ...
  ).*eta3+eta4.*k.^2).^(1/2)).*bessely(0,(sqrt(-1)*(-1)).*delta.*eta4.^( ...
  -1/2).*((sqrt(-1)*(-1)).*eta3+eta4.*k.^2).^(1/2).*zs)+(-2).*alpha.^3.* ...
  delta.^2.*eta2.*((sqrt(-1)*(-1)).*eta3+eta4.*k.^2).^(1/2).*phi.*psi.* ...
  Pvs.*besselj(1,sqrt(-1).*delta.*eta4.^(-1/2).*((sqrt(-1)*(-1)).*eta3+ ...
  eta4.*k.^2).^(1/2)).*bessely(0,(sqrt(-1)*(-1)).*delta.*eta4.^(-1/2).*(( ...
  sqrt(-1)*(-1)).*eta3+eta4.*k.^2).^(1/2).*zs)+(-2).*alpha.^2.*delta.^2.* ...
  eta3.*((sqrt(-1)*(-1)).*eta3+eta4.*k.^2).^(1/2).*phi.*psi.*Pvs.*besselj( ...
  1,sqrt(-1).*delta.*eta4.^(-1/2).*((sqrt(-1)*(-1)).*eta3+eta4.*k.^2).^( ...
  1/2)).*bessely(0,(sqrt(-1)*(-1)).*delta.*eta4.^(-1/2).*((sqrt(-1)*(-1)) ...
  .*eta3+eta4.*k.^2).^(1/2).*zs)+(sqrt(-1)*(-2)).*alpha.^2.*delta.^2.* ...
  eta4.*k.^2.*((sqrt(-1)*(-1)).*eta3+eta4.*k.^2).^(1/2).*phi.*psi.*Pvs.* ...
  besselj(1,sqrt(-1).*delta.*eta4.^(-1/2).*((sqrt(-1)*(-1)).*eta3+eta4.* ...
  k.^2).^(1/2)).*bessely(0,(sqrt(-1)*(-1)).*delta.*eta4.^(-1/2).*((sqrt( ...
  -1)*(-1)).*eta3+eta4.*k.^2).^(1/2).*zs)+(-2).*alpha.^2.*delta.*eta1.* ...
  eta3.*((sqrt(-1)*(-1)).*eta3+eta4.*k.^2).^(1/2).*nu.*phi.*psi.*Pvs.* ...
  besselj(1,sqrt(-1).*delta.*eta4.^(-1/2).*((sqrt(-1)*(-1)).*eta3+eta4.* ...
  k.^2).^(1/2)).*bessely(0,(sqrt(-1)*(-1)).*delta.*eta4.^(-1/2).*((sqrt( ...
  -1)*(-1)).*eta3+eta4.*k.^2).^(1/2).*zs)+(-2).*alpha.^2.*delta.*eta1.* ...
  eta3.*h.*((sqrt(-1)*(-1)).*eta3+eta4.*k.^2).^(1/2).*nu.*phi.*psi.*Pvs.* ...
  besselj(1,sqrt(-1).*delta.*eta4.^(-1/2).*((sqrt(-1)*(-1)).*eta3+eta4.* ...
  k.^2).^(1/2)).*bessely(0,(sqrt(-1)*(-1)).*delta.*eta4.^(-1/2).*((sqrt( ...
  -1)*(-1)).*eta3+eta4.*k.^2).^(1/2).*zs)+(sqrt(-1)*(-2)).*alpha.^2.* ...
  delta.*eta1.*eta4.*k.^2.*((sqrt(-1)*(-1)).*eta3+eta4.*k.^2).^(1/2).*nu.* ...
  phi.*psi.*Pvs.*besselj(1,sqrt(-1).*delta.*eta4.^(-1/2).*((sqrt(-1)*(-1)) ...
  .*eta3+eta4.*k.^2).^(1/2)).*bessely(0,(sqrt(-1)*(-1)).*delta.*eta4.^( ...
  -1/2).*((sqrt(-1)*(-1)).*eta3+eta4.*k.^2).^(1/2).*zs)+(sqrt(-1)*(-2)).* ...
  alpha.^2.*delta.*eta1.*eta4.*h.*k.^2.*((sqrt(-1)*(-1)).*eta3+eta4.*k.^2) ...
  .^(1/2).*nu.*phi.*psi.*Pvs.*besselj(1,sqrt(-1).*delta.*eta4.^(-1/2).*(( ...
  sqrt(-1)*(-1)).*eta3+eta4.*k.^2).^(1/2)).*bessely(0,(sqrt(-1)*(-1)).* ...
  delta.*eta4.^(-1/2).*((sqrt(-1)*(-1)).*eta3+eta4.*k.^2).^(1/2).*zs)+ ...
  alpha.^2.*delta.*eta2.*eta3.*h.*((sqrt(-1)*(-1)).*eta3+eta4.*k.^2).^( ...
  1/2).*phi.*pv1.*Pvs.*besselj(1,sqrt(-1).*delta.*eta4.^(-1/2).*((sqrt(-1) ...
  *(-1)).*eta3+eta4.*k.^2).^(1/2)).*bessely(0,(sqrt(-1)*(-1)).*delta.* ...
  eta4.^(-1/2).*((sqrt(-1)*(-1)).*eta3+eta4.*k.^2).^(1/2).*zs)+sqrt(-1).* ...
  alpha.^2.*delta.*eta2.*eta4.*h.*k.^2.*((sqrt(-1)*(-1)).*eta3+eta4.*k.^2) ...
  .^(1/2).*phi.*pv1.*Pvs.*besselj(1,sqrt(-1).*delta.*eta4.^(-1/2).*((sqrt( ...
  -1)*(-1)).*eta3+eta4.*k.^2).^(1/2)).*bessely(0,(sqrt(-1)*(-1)).*delta.* ...
  eta4.^(-1/2).*((sqrt(-1)*(-1)).*eta3+eta4.*k.^2).^(1/2).*zs)+alpha.^2.* ...
  delta.*eta2.*eta3.*((sqrt(-1)*(-1)).*eta3+eta4.*k.^2).^(1/2).*phi.* ...
  pvRi.*Pvs.*besselj(1,sqrt(-1).*delta.*eta4.^(-1/2).*((sqrt(-1)*(-1)).* ...
  eta3+eta4.*k.^2).^(1/2)).*bessely(0,(sqrt(-1)*(-1)).*delta.*eta4.^(-1/2) ...
  .*((sqrt(-1)*(-1)).*eta3+eta4.*k.^2).^(1/2).*zs)+(-1).*alpha.^2.*delta.* ...
  eta2.*eta3.*h.*((sqrt(-1)*(-1)).*eta3+eta4.*k.^2).^(1/2).*phi.*pvRi.* ...
  Pvs.*besselj(1,sqrt(-1).*delta.*eta4.^(-1/2).*((sqrt(-1)*(-1)).*eta3+ ...
  eta4.*k.^2).^(1/2)).*bessely(0,(sqrt(-1)*(-1)).*delta.*eta4.^(-1/2).*(( ...
  sqrt(-1)*(-1)).*eta3+eta4.*k.^2).^(1/2).*zs)+sqrt(-1).*alpha.^2.*delta.* ...
  eta2.*eta4.*k.^2.*((sqrt(-1)*(-1)).*eta3+eta4.*k.^2).^(1/2).*phi.*pvRi.* ...
  Pvs.*besselj(1,sqrt(-1).*delta.*eta4.^(-1/2).*((sqrt(-1)*(-1)).*eta3+ ...
  eta4.*k.^2).^(1/2)).*bessely(0,(sqrt(-1)*(-1)).*delta.*eta4.^(-1/2).*(( ...
  sqrt(-1)*(-1)).*eta3+eta4.*k.^2).^(1/2).*zs)+(sqrt(-1)*(-1)).*alpha.^2.* ...
  delta.*eta2.*eta4.*h.*k.^2.*((sqrt(-1)*(-1)).*eta3+eta4.*k.^2).^(1/2).* ...
  phi.*pvRi.*Pvs.*besselj(1,sqrt(-1).*delta.*eta4.^(-1/2).*((sqrt(-1)*(-1) ...
  ).*eta3+eta4.*k.^2).^(1/2)).*bessely(0,(sqrt(-1)*(-1)).*delta.*eta4.^( ...
  -1/2).*((sqrt(-1)*(-1)).*eta3+eta4.*k.^2).^(1/2).*zs)+2.*alpha.^3.* ...
  delta.^2.*eta2.*h.*((sqrt(-1)*(-1)).*eta3+eta4.*k.^2).^(1/2).*Pcs.*phi.* ...
  psi.*besselj(0,sqrt(-1).*delta.*eta4.^(-1/2).*((sqrt(-1)*(-1)).*eta3+ ...
  eta4.*k.^2).^(1/2)).*bessely(1,(sqrt(-1)*(-1)).*delta.*eta4.^(-1/2).*(( ...
  sqrt(-1)*(-1)).*eta3+eta4.*k.^2).^(1/2))+(-2).*alpha.^2.*delta.^2.* ...
  eta2.*h.*((sqrt(-1)*(-1)).*eta3+eta4.*k.^2).^(1/2).*Pes.*phi.*psi.* ...
  besselj(0,sqrt(-1).*delta.*eta4.^(-1/2).*((sqrt(-1)*(-1)).*eta3+eta4.* ...
  k.^2).^(1/2)).*bessely(1,(sqrt(-1)*(-1)).*delta.*eta4.^(-1/2).*((sqrt( ...
  -1)*(-1)).*eta3+eta4.*k.^2).^(1/2))+2.*alpha.^3.*delta.^2.*eta2.*h.*(( ...
  sqrt(-1)*(-1)).*eta3+eta4.*k.^2).^(1/2).*Pes.*phi.*psi.*besselj(0,sqrt( ...
  -1).*delta.*eta4.^(-1/2).*((sqrt(-1)*(-1)).*eta3+eta4.*k.^2).^(1/2)).* ...
  bessely(1,(sqrt(-1)*(-1)).*delta.*eta4.^(-1/2).*((sqrt(-1)*(-1)).*eta3+ ...
  eta4.*k.^2).^(1/2))+2.*alpha.^3.*delta.^2.*eta2.*h.*((sqrt(-1)*(-1)).* ...
  eta3+eta4.*k.^2).^(1/2).*phi.*psi.*Pvs.*besselj(0,sqrt(-1).*delta.* ...
  eta4.^(-1/2).*((sqrt(-1)*(-1)).*eta3+eta4.*k.^2).^(1/2)).*bessely(1,( ...
  sqrt(-1)*(-1)).*delta.*eta4.^(-1/2).*((sqrt(-1)*(-1)).*eta3+eta4.*k.^2) ...
  .^(1/2))+alpha.*besselj(0,sqrt(-1).*delta.*eta4.^(-1/2).*((sqrt(-1)*(-1) ...
  ).*eta3+eta4.*k.^2).^(1/2).*Ri).*((-2).*alpha.^2.*delta.*eta2.*eta4.^( ...
  1/2).*eta6.*h.*((-1)+phi).*psi.*bessely(0,(sqrt(-1)*(-1)).*delta.* ...
  eta4.^(-1/2).*((sqrt(-1)*(-1)).*eta3+eta4.*k.^2).^(1/2))+eta4.^(1/2).*( ...
  2.*alpha.^2.*delta.*eta2.*eta6.*h.*((-1)+phi).*psi+eta2.*(eta3+sqrt(-1) ...
  .*eta4.*k.^2).*(eta6.*h.*P0.*((-1)+phi)+(sqrt(-1)*(-1)).*delta.*((-1)+h) ...
  .*Pes.*Rey.*vr0)+(-1).*alpha.*(eta3+sqrt(-1).*eta4.*k.^2).*(eta6.*h.*(( ...
  -1)+phi).*((-4).*eta1.*nu.*psi+eta2.*(pc1+pv1))+delta.*(2.*dvr0.*eta5.* ...
  eta6.*((-1)+phi)+(sqrt(-1)*(-1)).*((sqrt(-1)*(-2)).*eta6.*h.*((-1)+phi) ...
  .*psi+eta2.*((-1)+h).*(Pcs+Pes+Pvs).*Rey.*vr0)))).*bessely(0,(sqrt(-1)*( ...
  -1)).*delta.*eta4.^(-1/2).*((sqrt(-1)*(-1)).*eta3+eta4.*k.^2).^(1/2).* ...
  zs)+(-2).*alpha.*delta.^2.*eta2.*((-1)+h).*((sqrt(-1)*(-1)).*eta3+eta4.* ...
  k.^2).^(1/2).*phi.*psi.*((-1).*Pes+alpha.*(Pcs+Pes+Pvs)).*bessely(1,( ...
  sqrt(-1)*(-1)).*delta.*eta4.^(-1/2).*((sqrt(-1)*(-1)).*eta3+eta4.*k.^2) ...
  .^(1/2)))+besselj(0,sqrt(-1).*delta.*eta4.^(-1/2).*((sqrt(-1)*(-1)).* ...
  eta3+eta4.*k.^2).^(1/2).*zs).*(alpha.*eta4.^(1/2).*h.*(2.*alpha.^2.* ...
  delta.*eta2.*eta6.*((-1)+phi).*psi+delta.*eta2.*((sqrt(-1)*(-1)).*eta3+ ...
  eta4.*k.^2).*Pes.*Rey.*vr0+(-1).*alpha.*(eta3+sqrt(-1).*eta4.*k.^2).*(( ...
  -2).*eta6.*(delta+eta1.*nu).*((-1)+phi).*psi+eta2.*(eta6.*((-1)+phi).*( ...
  pcRi+pvRi)+(sqrt(-1)*(-1)).*delta.*(Pcs+Pes+Pvs).*Rey.*vr0))).*bessely( ...
  0,(sqrt(-1)*(-1)).*delta.*eta4.^(-1/2).*((sqrt(-1)*(-1)).*eta3+eta4.* ...
  k.^2).^(1/2))+alpha.*eta4.^(1/2).*((-2).*alpha.^2.*delta.*eta2.*eta6.* ...
  h.*((-1)+phi).*psi+(-1).*eta2.*(eta3+sqrt(-1).*eta4.*k.^2).*(eta6.*h.* ...
  P0.*((-1)+phi)+(sqrt(-1)*(-1)).*delta.*((-1)+h).*Pes.*Rey.*vr0)+alpha.*( ...
  eta3+sqrt(-1).*eta4.*k.^2).*(eta6.*h.*((-1)+phi).*((-4).*eta1.*nu.*psi+ ...
  eta2.*(pc1+pv1))+delta.*(2.*dvr0.*eta5.*eta6.*((-1)+phi)+(sqrt(-1)*(-1)) ...
  .*((sqrt(-1)*(-2)).*eta6.*h.*((-1)+phi).*psi+eta2.*((-1)+h).*(Pcs+Pes+ ...
  Pvs).*Rey.*vr0)))).*bessely(0,(sqrt(-1)*(-1)).*delta.*eta4.^(-1/2).*(( ...
  sqrt(-1)*(-1)).*eta3+eta4.*k.^2).^(1/2).*Ri)+delta.*((sqrt(-1)*(-1)).* ...
  eta3+eta4.*k.^2).^(1/2).*phi.*((-1).*eta2.*h.*(eta3+sqrt(-1).*eta4.* ...
  k.^2).*P0+(-2).*alpha.^2.*delta.*eta2.*psi+alpha.*(eta3+sqrt(-1).*eta4.* ...
  k.^2).*(2.*delta.*(dvr0.*eta5+(-1).*psi)+(-2).*eta1.*(1+h).*nu.*psi+ ...
  eta2.*(pcRi+h.*(pc1+(-1).*pcRi+pv1+(-1).*pvRi)+pvRi))).*((-1).*Pes+ ...
  alpha.*(Pcs+Pes+Pvs)).*bessely(1,(sqrt(-1)*(-1)).*delta.*eta4.^(-1/2).*( ...
  (sqrt(-1)*(-1)).*eta3+eta4.*k.^2).^(1/2))));

pep=Pes.*Pdim+2*Pdim*real(pe);
plot(zs,pep)
ylabel('Cerebrospinal fluid pressure in the SC [Pa]')
xlabel('Dimensionless radial coordinate zs')